# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import CommandCenter
from CommandCenter.api.computes_api import ComputesApi  # noqa: E501
from CommandCenter.rest import ApiException


class TestComputesApi(unittest.TestCase):
    """ComputesApi unit test stubs"""

    def setUp(self):
        self.api = CommandCenter.api.computes_api.ComputesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_compute(self):
        """Test case for create_compute

        """
        pass

    def test_delete_compute(self):
        """Test case for delete_compute

        """
        pass

    def test_edit_compute(self):
        """Test case for edit_compute

        """
        pass

    def test_get_compute_details(self):
        """Test case for get_compute_details

        """
        pass

    def test_list_type_computes(self):
        """Test case for list_type_computes

        """
        pass


if __name__ == '__main__':
    unittest.main()
