# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import CommandCenter
from CommandCenter.api.drive_api import DriveApi  # noqa: E501
from CommandCenter.rest import ApiException


class TestDriveApi(unittest.TestCase):
    """DriveApi unit test stubs"""

    def setUp(self):
        self.api = CommandCenter.api.drive_api.DriveApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_designates_drive_as_cache_drive(self):
        """Test case for designates_drive_as_cache_drive

        """
        pass

    def test_disable_drive(self):
        """Test case for disable_drive

        """
        pass

    def test_disable_drives_led(self):
        """Test case for disable_drives_led

        """
        pass

    def test_enable_drive(self):
        """Test case for enable_drive

        """
        pass

    def test_enable_drives_led(self):
        """Test case for enable_drives_led

        """
        pass

    def test_get_all_drives(self):
        """Test case for get_all_drives

        """
        pass

    def test_get_drive(self):
        """Test case for get_drive

        """
        pass

    def test_get_drive_smart(self):
        """Test case for get_drive_smart

        """
        pass

    def test_get_drive_smart_test_results(self):
        """Test case for get_drive_smart_test_results

        """
        pass

    def test_get_drives_details_end_location(self):
        """Test case for get_drives_details_end_location

        """
        pass

    def test_license_an_availiable_drive(self):
        """Test case for license_an_availiable_drive

        """
        pass

    def test_list_drive_comments(self):
        """Test case for list_drive_comments

        """
        pass

    def test_remove_drive(self):
        """Test case for remove_drive

        """
        pass

    def test_replace_allocated_drive(self):
        """Test case for replace_allocated_drive

        """
        pass

    def test_run_drive_smart_test(self):
        """Test case for run_drive_smart_test

        """
        pass

    def test_show_drives_metered_performane_information(self):
        """Test case for show_drives_metered_performane_information

        """
        pass

    def test_undesignate_drive_as_cache_drive(self):
        """Test case for undesignate_drive_as_cache_drive

        """
        pass

    def test_unlicense_an_availiable_drive(self):
        """Test case for unlicense_an_availiable_drive

        """
        pass


if __name__ == '__main__':
    unittest.main()
