# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import Vpsa
from Vpsa.api.pools_api import PoolsApi  # noqa: E501
from Vpsa.rest import ApiException


class TestPoolsApi(unittest.TestCase):
    """PoolsApi unit test stubs"""

    def setUp(self):
        self.api = Vpsa.api.pools_api.PoolsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cancel_shrink_pool(self):
        """Test case for cancel_shrink_pool

        """
        pass

    def test_create_pool(self):
        """Test case for create_pool

        """
        pass

    def test_delete_pool(self):
        """Test case for delete_pool

        """
        pass

    def test_expand_pool(self):
        """Test case for expand_pool

        """
        pass

    def test_get_all_pools(self):
        """Test case for get_all_pools

        """
        pass

    def test_get_pool(self):
        """Test case for get_pool

        """
        pass

    def test_get_pool_destination_volume_data(self):
        """Test case for get_pool_destination_volume_data

        """
        pass

    def test_get_pool_mirror_destination_volumes(self):
        """Test case for get_pool_mirror_destination_volumes

        """
        pass

    def test_get_pool_performance(self):
        """Test case for get_pool_performance

        """
        pass

    def test_get_raid_groups_in_pool(self):
        """Test case for get_raid_groups_in_pool

        """
        pass

    def test_get_volumes_in_pool(self):
        """Test case for get_volumes_in_pool

        """
        pass

    def test_get_volumes_in_pool_recycle_bin(self):
        """Test case for get_volumes_in_pool_recycle_bin

        """
        pass

    def test_rename_pool(self):
        """Test case for rename_pool

        """
        pass

    def test_set_pool_cache(self):
        """Test case for set_pool_cache

        """
        pass

    def test_set_pool_cowcache(self):
        """Test case for set_pool_cowcache

        """
        pass

    def test_shrink_pool(self):
        """Test case for shrink_pool

        """
        pass

    def test_update_pool_capacity_alerts(self):
        """Test case for update_pool_capacity_alerts

        """
        pass

    def test_update_ssd_cool_off(self):
        """Test case for update_ssd_cool_off

        """
        pass


if __name__ == '__main__':
    unittest.main()
