# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class InlineResponse20099VirtualNetworks(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'vlan': 'int',
        'custom_network_id': 'int',
        'netmask': 'str',
        'vni_id': 'int',
        'cidr': 'str',
        'gateway': 'str'
    }

    attribute_map = {
        'name': 'name',
        'vlan': 'vlan',
        'custom_network_id': 'custom_network_id',
        'netmask': 'netmask',
        'vni_id': 'vni_id',
        'cidr': 'cidr',
        'gateway': 'gateway'
    }

    def __init__(self, name=None, vlan=None, custom_network_id=None, netmask=None, vni_id=None, cidr=None, gateway=None, _configuration=None):  # noqa: E501
        """InlineResponse20099VirtualNetworks - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._vlan = None
        self._custom_network_id = None
        self._netmask = None
        self._vni_id = None
        self._cidr = None
        self._gateway = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if vlan is not None:
            self.vlan = vlan
        if custom_network_id is not None:
            self.custom_network_id = custom_network_id
        if netmask is not None:
            self.netmask = netmask
        if vni_id is not None:
            self.vni_id = vni_id
        if cidr is not None:
            self.cidr = cidr
        if gateway is not None:
            self.gateway = gateway

    @property
    def name(self):
        """Gets the name of this InlineResponse20099VirtualNetworks.  # noqa: E501


        :return: The name of this InlineResponse20099VirtualNetworks.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse20099VirtualNetworks.


        :param name: The name of this InlineResponse20099VirtualNetworks.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def vlan(self):
        """Gets the vlan of this InlineResponse20099VirtualNetworks.  # noqa: E501


        :return: The vlan of this InlineResponse20099VirtualNetworks.  # noqa: E501
        :rtype: int
        """
        return self._vlan

    @vlan.setter
    def vlan(self, vlan):
        """Sets the vlan of this InlineResponse20099VirtualNetworks.


        :param vlan: The vlan of this InlineResponse20099VirtualNetworks.  # noqa: E501
        :type: int
        """

        self._vlan = vlan

    @property
    def custom_network_id(self):
        """Gets the custom_network_id of this InlineResponse20099VirtualNetworks.  # noqa: E501


        :return: The custom_network_id of this InlineResponse20099VirtualNetworks.  # noqa: E501
        :rtype: int
        """
        return self._custom_network_id

    @custom_network_id.setter
    def custom_network_id(self, custom_network_id):
        """Sets the custom_network_id of this InlineResponse20099VirtualNetworks.


        :param custom_network_id: The custom_network_id of this InlineResponse20099VirtualNetworks.  # noqa: E501
        :type: int
        """

        self._custom_network_id = custom_network_id

    @property
    def netmask(self):
        """Gets the netmask of this InlineResponse20099VirtualNetworks.  # noqa: E501


        :return: The netmask of this InlineResponse20099VirtualNetworks.  # noqa: E501
        :rtype: str
        """
        return self._netmask

    @netmask.setter
    def netmask(self, netmask):
        """Sets the netmask of this InlineResponse20099VirtualNetworks.


        :param netmask: The netmask of this InlineResponse20099VirtualNetworks.  # noqa: E501
        :type: str
        """

        self._netmask = netmask

    @property
    def vni_id(self):
        """Gets the vni_id of this InlineResponse20099VirtualNetworks.  # noqa: E501


        :return: The vni_id of this InlineResponse20099VirtualNetworks.  # noqa: E501
        :rtype: int
        """
        return self._vni_id

    @vni_id.setter
    def vni_id(self, vni_id):
        """Sets the vni_id of this InlineResponse20099VirtualNetworks.


        :param vni_id: The vni_id of this InlineResponse20099VirtualNetworks.  # noqa: E501
        :type: int
        """

        self._vni_id = vni_id

    @property
    def cidr(self):
        """Gets the cidr of this InlineResponse20099VirtualNetworks.  # noqa: E501


        :return: The cidr of this InlineResponse20099VirtualNetworks.  # noqa: E501
        :rtype: str
        """
        return self._cidr

    @cidr.setter
    def cidr(self, cidr):
        """Sets the cidr of this InlineResponse20099VirtualNetworks.


        :param cidr: The cidr of this InlineResponse20099VirtualNetworks.  # noqa: E501
        :type: str
        """

        self._cidr = cidr

    @property
    def gateway(self):
        """Gets the gateway of this InlineResponse20099VirtualNetworks.  # noqa: E501


        :return: The gateway of this InlineResponse20099VirtualNetworks.  # noqa: E501
        :rtype: str
        """
        return self._gateway

    @gateway.setter
    def gateway(self, gateway):
        """Sets the gateway of this InlineResponse20099VirtualNetworks.


        :param gateway: The gateway of this InlineResponse20099VirtualNetworks.  # noqa: E501
        :type: str
        """

        self._gateway = gateway

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20099VirtualNetworks, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20099VirtualNetworks):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20099VirtualNetworks):
            return True

        return self.to_dict() != other.to_dict()
