# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import CommandCenter
from CommandCenter.api.clouds_api import CloudsApi  # noqa: E501
from CommandCenter.rest import ApiException


class TestCloudsApi(unittest.TestCase):
    """CloudsApi unit test stubs"""

    def setUp(self):
        self.api = CommandCenter.api.clouds_api.CloudsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_cloud_vms_zsnap(self):
        """Test case for create_cloud_vms_zsnap

        """
        pass

    def test_get_all_clouds(self):
        """Test case for get_all_clouds

        """
        pass

    def test_get_cloud(self):
        """Test case for get_cloud

        """
        pass

    def test_get_redundancy_level_policies(self):
        """Test case for get_redundancy_level_policies

        """
        pass

    def test_list_cloud_public_ips(self):
        """Test case for list_cloud_public_ips

        """
        pass

    def test_rename_cloud(self):
        """Test case for rename_cloud

        """
        pass

    def test_set_cube_from_local_repo(self):
        """Test case for set_cube_from_local_repo

        """
        pass

    def test_shutdown_cloud(self):
        """Test case for shutdown_cloud

        """
        pass

    def test_upgrade_cloud(self):
        """Test case for upgrade_cloud

        """
        pass


if __name__ == '__main__':
    unittest.main()
