# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class UpdateVolPerfThreshold(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'read_iops_limit': 'int',
        'read_mbps_limit': 'int',
        'read_latency_limit': 'int',
        'write_iops_limit': 'int',
        'write_mbps_limit': 'int',
        'write_latency_limit': 'int'
    }

    attribute_map = {
        'read_iops_limit': 'read_iops_limit',
        'read_mbps_limit': 'read_mbps_limit',
        'read_latency_limit': 'read_latency_limit',
        'write_iops_limit': 'write_iops_limit',
        'write_mbps_limit': 'write_mbps_limit',
        'write_latency_limit': 'write_latency_limit'
    }

    def __init__(self, read_iops_limit=None, read_mbps_limit=None, read_latency_limit=None, write_iops_limit=None, write_mbps_limit=None, write_latency_limit=None, _configuration=None):  # noqa: E501
        """UpdateVolPerfThreshold - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._read_iops_limit = None
        self._read_mbps_limit = None
        self._read_latency_limit = None
        self._write_iops_limit = None
        self._write_mbps_limit = None
        self._write_latency_limit = None
        self.discriminator = None

        if read_iops_limit is not None:
            self.read_iops_limit = read_iops_limit
        if read_mbps_limit is not None:
            self.read_mbps_limit = read_mbps_limit
        if read_latency_limit is not None:
            self.read_latency_limit = read_latency_limit
        if write_iops_limit is not None:
            self.write_iops_limit = write_iops_limit
        if write_mbps_limit is not None:
            self.write_mbps_limit = write_mbps_limit
        if write_latency_limit is not None:
            self.write_latency_limit = write_latency_limit

    @property
    def read_iops_limit(self):
        """Gets the read_iops_limit of this UpdateVolPerfThreshold.  # noqa: E501

        Alert me when the average read IOPS for this volume exceeds this number of IOPS.  # noqa: E501

        :return: The read_iops_limit of this UpdateVolPerfThreshold.  # noqa: E501
        :rtype: int
        """
        return self._read_iops_limit

    @read_iops_limit.setter
    def read_iops_limit(self, read_iops_limit):
        """Sets the read_iops_limit of this UpdateVolPerfThreshold.

        Alert me when the average read IOPS for this volume exceeds this number of IOPS.  # noqa: E501

        :param read_iops_limit: The read_iops_limit of this UpdateVolPerfThreshold.  # noqa: E501
        :type: int
        """

        self._read_iops_limit = read_iops_limit

    @property
    def read_mbps_limit(self):
        """Gets the read_mbps_limit of this UpdateVolPerfThreshold.  # noqa: E501

        Alert me when the average read throughput for this volume exceeds this number of MB/s.  # noqa: E501

        :return: The read_mbps_limit of this UpdateVolPerfThreshold.  # noqa: E501
        :rtype: int
        """
        return self._read_mbps_limit

    @read_mbps_limit.setter
    def read_mbps_limit(self, read_mbps_limit):
        """Sets the read_mbps_limit of this UpdateVolPerfThreshold.

        Alert me when the average read throughput for this volume exceeds this number of MB/s.  # noqa: E501

        :param read_mbps_limit: The read_mbps_limit of this UpdateVolPerfThreshold.  # noqa: E501
        :type: int
        """

        self._read_mbps_limit = read_mbps_limit

    @property
    def read_latency_limit(self):
        """Gets the read_latency_limit of this UpdateVolPerfThreshold.  # noqa: E501

        Alert me when the average read latency for this volume exceeds this number of ms.  # noqa: E501

        :return: The read_latency_limit of this UpdateVolPerfThreshold.  # noqa: E501
        :rtype: int
        """
        return self._read_latency_limit

    @read_latency_limit.setter
    def read_latency_limit(self, read_latency_limit):
        """Sets the read_latency_limit of this UpdateVolPerfThreshold.

        Alert me when the average read latency for this volume exceeds this number of ms.  # noqa: E501

        :param read_latency_limit: The read_latency_limit of this UpdateVolPerfThreshold.  # noqa: E501
        :type: int
        """

        self._read_latency_limit = read_latency_limit

    @property
    def write_iops_limit(self):
        """Gets the write_iops_limit of this UpdateVolPerfThreshold.  # noqa: E501

        Alert me when the average write IOPS for this volume exceeds this number of IOPS.  # noqa: E501

        :return: The write_iops_limit of this UpdateVolPerfThreshold.  # noqa: E501
        :rtype: int
        """
        return self._write_iops_limit

    @write_iops_limit.setter
    def write_iops_limit(self, write_iops_limit):
        """Sets the write_iops_limit of this UpdateVolPerfThreshold.

        Alert me when the average write IOPS for this volume exceeds this number of IOPS.  # noqa: E501

        :param write_iops_limit: The write_iops_limit of this UpdateVolPerfThreshold.  # noqa: E501
        :type: int
        """

        self._write_iops_limit = write_iops_limit

    @property
    def write_mbps_limit(self):
        """Gets the write_mbps_limit of this UpdateVolPerfThreshold.  # noqa: E501

        Alert me when the average write throughput for this volume exceeds this number of MB/s.  # noqa: E501

        :return: The write_mbps_limit of this UpdateVolPerfThreshold.  # noqa: E501
        :rtype: int
        """
        return self._write_mbps_limit

    @write_mbps_limit.setter
    def write_mbps_limit(self, write_mbps_limit):
        """Sets the write_mbps_limit of this UpdateVolPerfThreshold.

        Alert me when the average write throughput for this volume exceeds this number of MB/s.  # noqa: E501

        :param write_mbps_limit: The write_mbps_limit of this UpdateVolPerfThreshold.  # noqa: E501
        :type: int
        """

        self._write_mbps_limit = write_mbps_limit

    @property
    def write_latency_limit(self):
        """Gets the write_latency_limit of this UpdateVolPerfThreshold.  # noqa: E501

        Alert me when the average write latency for this volume exceeds this number of ms.  # noqa: E501

        :return: The write_latency_limit of this UpdateVolPerfThreshold.  # noqa: E501
        :rtype: int
        """
        return self._write_latency_limit

    @write_latency_limit.setter
    def write_latency_limit(self, write_latency_limit):
        """Sets the write_latency_limit of this UpdateVolPerfThreshold.

        Alert me when the average write latency for this volume exceeds this number of ms.  # noqa: E501

        :param write_latency_limit: The write_latency_limit of this UpdateVolPerfThreshold.  # noqa: E501
        :type: int
        """

        self._write_latency_limit = write_latency_limit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateVolPerfThreshold, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateVolPerfThreshold):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateVolPerfThreshold):
            return True

        return self.to_dict() != other.to_dict()
