# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class InlineResponse2001Clouds(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'resources': 'InlineResponse2001Resources',
        'inventory': 'list[InlineResponse2001Inventory]',
        'networking': 'InlineResponse2001Networking'
    }

    attribute_map = {
        'name': 'name',
        'resources': 'resources',
        'inventory': 'inventory',
        'networking': 'networking'
    }

    def __init__(self, name=None, resources=None, inventory=None, networking=None, _configuration=None):  # noqa: E501
        """InlineResponse2001Clouds - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._resources = None
        self._inventory = None
        self._networking = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if resources is not None:
            self.resources = resources
        if inventory is not None:
            self.inventory = inventory
        if networking is not None:
            self.networking = networking

    @property
    def name(self):
        """Gets the name of this InlineResponse2001Clouds.  # noqa: E501


        :return: The name of this InlineResponse2001Clouds.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse2001Clouds.


        :param name: The name of this InlineResponse2001Clouds.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def resources(self):
        """Gets the resources of this InlineResponse2001Clouds.  # noqa: E501


        :return: The resources of this InlineResponse2001Clouds.  # noqa: E501
        :rtype: InlineResponse2001Resources
        """
        return self._resources

    @resources.setter
    def resources(self, resources):
        """Sets the resources of this InlineResponse2001Clouds.


        :param resources: The resources of this InlineResponse2001Clouds.  # noqa: E501
        :type: InlineResponse2001Resources
        """

        self._resources = resources

    @property
    def inventory(self):
        """Gets the inventory of this InlineResponse2001Clouds.  # noqa: E501


        :return: The inventory of this InlineResponse2001Clouds.  # noqa: E501
        :rtype: list[InlineResponse2001Inventory]
        """
        return self._inventory

    @inventory.setter
    def inventory(self, inventory):
        """Sets the inventory of this InlineResponse2001Clouds.


        :param inventory: The inventory of this InlineResponse2001Clouds.  # noqa: E501
        :type: list[InlineResponse2001Inventory]
        """

        self._inventory = inventory

    @property
    def networking(self):
        """Gets the networking of this InlineResponse2001Clouds.  # noqa: E501


        :return: The networking of this InlineResponse2001Clouds.  # noqa: E501
        :rtype: InlineResponse2001Networking
        """
        return self._networking

    @networking.setter
    def networking(self, networking):
        """Sets the networking of this InlineResponse2001Clouds.


        :param networking: The networking of this InlineResponse2001Clouds.  # noqa: E501
        :type: InlineResponse2001Networking
        """

        self._networking = networking

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse2001Clouds, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse2001Clouds):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse2001Clouds):
            return True

        return self.to_dict() != other.to_dict()
