# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import Vpsa
from Vpsa.api.servers_api import ServersApi  # noqa: E501
from Vpsa.rest import ApiException


class TestServersApi(unittest.TestCase):
    """ServersApi unit test stubs"""

    def setUp(self):
        self.api = Vpsa.api.servers_api.ServersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_attach_servers_to_volume(self):
        """Test case for attach_servers_to_volume

        """
        pass

    def test_create_server(self):
        """Test case for create_server

        """
        pass

    def test_delete_server(self):
        """Test case for delete_server

        """
        pass

    def test_delete_server_session(self):
        """Test case for delete_server_session

        """
        pass

    def test_get_all_servers(self):
        """Test case for get_all_servers

        """
        pass

    def test_get_server(self):
        """Test case for get_server

        """
        pass

    def test_get_server_performance(self):
        """Test case for get_server_performance

        """
        pass

    def test_get_volumes_attached_to_server(self):
        """Test case for get_volumes_attached_to_server

        """
        pass

    def test_list_server_sessions(self):
        """Test case for list_server_sessions

        """
        pass

    def test_rename_server(self):
        """Test case for rename_server

        """
        pass

    def test_update_server(self):
        """Test case for update_server

        """
        pass


if __name__ == '__main__':
    unittest.main()
