# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import CommandCenter
from CommandCenter.api.roles_api import RolesApi  # noqa: E501
from CommandCenter.rest import ApiException


class TestRolesApi(unittest.TestCase):
    """RolesApi unit test stubs"""

    def setUp(self):
        self.api = CommandCenter.api.roles_api.RolesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_role(self):
        """Test case for create_role

        """
        pass

    def test_delete_role(self):
        """Test case for delete_role

        """
        pass

    def test_edit_role(self):
        """Test case for edit_role

        """
        pass

    def test_get_role(self):
        """Test case for get_role

        """
        pass

    def test_list_all_permissions(self):
        """Test case for list_all_permissions

        """
        pass

    def test_list_roles(self):
        """Test case for list_roles

        """
        pass


if __name__ == '__main__':
    unittest.main()
