# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import CommandCenter
from CommandCenter.api.users_api import UsersApi  # noqa: E501
from CommandCenter.rest import ApiException


class TestUsersApi(unittest.TestCase):
    """UsersApi unit test stubs"""

    def setUp(self):
        self.api = CommandCenter.api.users_api.UsersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_user(self):
        """Test case for create_user

        """
        pass

    def test_delete_user(self):
        """Test case for delete_user

        """
        pass

    def test_get_all_users(self):
        """Test case for get_all_users

        """
        pass

    def test_get_user(self):
        """Test case for get_user

        """
        pass

    def test_get_user_api_key(self):
        """Test case for get_user_api_key

        """
        pass

    def test_regenerate_user_api_token(self):
        """Test case for regenerate_user_api_token

        """
        pass

    def test_update_user(self):
        """Test case for update_user

        """
        pass


if __name__ == '__main__':
    unittest.main()
