# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import CommandCenter
from CommandCenter.api.software_install_api import SoftwareInstallApi  # noqa: E501
from CommandCenter.rest import ApiException


class TestSoftwareInstallApi(unittest.TestCase):
    """SoftwareInstallApi unit test stubs"""

    def setUp(self):
        self.api = CommandCenter.api.software_install_api.SoftwareInstallApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_abort_last_action(self):
        """Test case for abort_last_action

        """
        pass

    def test_cloud_upgrade(self):
        """Test case for cloud_upgrade

        """
        pass

    def test_download_package(self):
        """Test case for download_package

        """
        pass

    def test_erase_package(self):
        """Test case for erase_package

        """
        pass

    def test_list_packages(self):
        """Test case for list_packages

        """
        pass

    def test_list_sns(self):
        """Test case for list_sns

        """
        pass

    def test_register_images(self):
        """Test case for register_images

        """
        pass

    def test_restart_last_action(self):
        """Test case for restart_last_action

        """
        pass

    def test_show_all(self):
        """Test case for show_all

        """
        pass

    def test_sn_install(self):
        """Test case for sn_install

        """
        pass

    def test_upload_settings(self):
        """Test case for upload_settings

        """
        pass


if __name__ == '__main__':
    unittest.main()
