# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class InlineResponse20016CustomNetwork(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'user': 'str',
        'cidr': 'str',
        'gateway': 'str',
        'vlan_id': 'str',
        'id': 'str',
        'reserved': 'bool',
        'default_for_tenant': 'bool',
        'allocatable_ip_ranges': 'list[str]'
    }

    attribute_map = {
        'name': 'name',
        'user': 'user',
        'cidr': 'cidr',
        'gateway': 'gateway',
        'vlan_id': 'vlan_id',
        'id': 'id',
        'reserved': 'reserved',
        'default_for_tenant': 'default_for_tenant',
        'allocatable_ip_ranges': 'allocatable_ip_ranges'
    }

    def __init__(self, name=None, user=None, cidr=None, gateway=None, vlan_id=None, id=None, reserved=None, default_for_tenant=None, allocatable_ip_ranges=None, _configuration=None):  # noqa: E501
        """InlineResponse20016CustomNetwork - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._user = None
        self._cidr = None
        self._gateway = None
        self._vlan_id = None
        self._id = None
        self._reserved = None
        self._default_for_tenant = None
        self._allocatable_ip_ranges = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if user is not None:
            self.user = user
        if cidr is not None:
            self.cidr = cidr
        if gateway is not None:
            self.gateway = gateway
        if vlan_id is not None:
            self.vlan_id = vlan_id
        if id is not None:
            self.id = id
        if reserved is not None:
            self.reserved = reserved
        if default_for_tenant is not None:
            self.default_for_tenant = default_for_tenant
        if allocatable_ip_ranges is not None:
            self.allocatable_ip_ranges = allocatable_ip_ranges

    @property
    def name(self):
        """Gets the name of this InlineResponse20016CustomNetwork.  # noqa: E501


        :return: The name of this InlineResponse20016CustomNetwork.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse20016CustomNetwork.


        :param name: The name of this InlineResponse20016CustomNetwork.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def user(self):
        """Gets the user of this InlineResponse20016CustomNetwork.  # noqa: E501


        :return: The user of this InlineResponse20016CustomNetwork.  # noqa: E501
        :rtype: str
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this InlineResponse20016CustomNetwork.


        :param user: The user of this InlineResponse20016CustomNetwork.  # noqa: E501
        :type: str
        """

        self._user = user

    @property
    def cidr(self):
        """Gets the cidr of this InlineResponse20016CustomNetwork.  # noqa: E501


        :return: The cidr of this InlineResponse20016CustomNetwork.  # noqa: E501
        :rtype: str
        """
        return self._cidr

    @cidr.setter
    def cidr(self, cidr):
        """Sets the cidr of this InlineResponse20016CustomNetwork.


        :param cidr: The cidr of this InlineResponse20016CustomNetwork.  # noqa: E501
        :type: str
        """

        self._cidr = cidr

    @property
    def gateway(self):
        """Gets the gateway of this InlineResponse20016CustomNetwork.  # noqa: E501


        :return: The gateway of this InlineResponse20016CustomNetwork.  # noqa: E501
        :rtype: str
        """
        return self._gateway

    @gateway.setter
    def gateway(self, gateway):
        """Sets the gateway of this InlineResponse20016CustomNetwork.


        :param gateway: The gateway of this InlineResponse20016CustomNetwork.  # noqa: E501
        :type: str
        """

        self._gateway = gateway

    @property
    def vlan_id(self):
        """Gets the vlan_id of this InlineResponse20016CustomNetwork.  # noqa: E501


        :return: The vlan_id of this InlineResponse20016CustomNetwork.  # noqa: E501
        :rtype: str
        """
        return self._vlan_id

    @vlan_id.setter
    def vlan_id(self, vlan_id):
        """Sets the vlan_id of this InlineResponse20016CustomNetwork.


        :param vlan_id: The vlan_id of this InlineResponse20016CustomNetwork.  # noqa: E501
        :type: str
        """

        self._vlan_id = vlan_id

    @property
    def id(self):
        """Gets the id of this InlineResponse20016CustomNetwork.  # noqa: E501


        :return: The id of this InlineResponse20016CustomNetwork.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InlineResponse20016CustomNetwork.


        :param id: The id of this InlineResponse20016CustomNetwork.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def reserved(self):
        """Gets the reserved of this InlineResponse20016CustomNetwork.  # noqa: E501


        :return: The reserved of this InlineResponse20016CustomNetwork.  # noqa: E501
        :rtype: bool
        """
        return self._reserved

    @reserved.setter
    def reserved(self, reserved):
        """Sets the reserved of this InlineResponse20016CustomNetwork.


        :param reserved: The reserved of this InlineResponse20016CustomNetwork.  # noqa: E501
        :type: bool
        """

        self._reserved = reserved

    @property
    def default_for_tenant(self):
        """Gets the default_for_tenant of this InlineResponse20016CustomNetwork.  # noqa: E501


        :return: The default_for_tenant of this InlineResponse20016CustomNetwork.  # noqa: E501
        :rtype: bool
        """
        return self._default_for_tenant

    @default_for_tenant.setter
    def default_for_tenant(self, default_for_tenant):
        """Sets the default_for_tenant of this InlineResponse20016CustomNetwork.


        :param default_for_tenant: The default_for_tenant of this InlineResponse20016CustomNetwork.  # noqa: E501
        :type: bool
        """

        self._default_for_tenant = default_for_tenant

    @property
    def allocatable_ip_ranges(self):
        """Gets the allocatable_ip_ranges of this InlineResponse20016CustomNetwork.  # noqa: E501


        :return: The allocatable_ip_ranges of this InlineResponse20016CustomNetwork.  # noqa: E501
        :rtype: list[str]
        """
        return self._allocatable_ip_ranges

    @allocatable_ip_ranges.setter
    def allocatable_ip_ranges(self, allocatable_ip_ranges):
        """Sets the allocatable_ip_ranges of this InlineResponse20016CustomNetwork.


        :param allocatable_ip_ranges: The allocatable_ip_ranges of this InlineResponse20016CustomNetwork.  # noqa: E501
        :type: list[str]
        """

        self._allocatable_ip_ranges = allocatable_ip_ranges

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20016CustomNetwork, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20016CustomNetwork):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20016CustomNetwork):
            return True

        return self.to_dict() != other.to_dict()
