# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import CommandCenter
from CommandCenter.api.custom_networks_api import CustomNetworksApi  # noqa: E501
from CommandCenter.rest import ApiException


class TestCustomNetworksApi(unittest.TestCase):
    """CustomNetworksApi unit test stubs"""

    def setUp(self):
        self.api = CommandCenter.api.custom_networks_api.CustomNetworksApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_ip_range_to_custom_net(self):
        """Test case for add_ip_range_to_custom_net

        """
        pass

    def test_create_custom_network(self):
        """Test case for create_custom_network

        """
        pass

    def test_delete_custom_network(self):
        """Test case for delete_custom_network

        """
        pass

    def test_get_all_custom_networks(self):
        """Test case for get_all_custom_networks

        """
        pass

    def test_get_custom_network(self):
        """Test case for get_custom_network

        """
        pass

    def test_remove_ip_range_from_custom_net(self):
        """Test case for remove_ip_range_from_custom_net

        """
        pass


if __name__ == '__main__':
    unittest.main()
