# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import CommandCenter
from CommandCenter.api.vpsa_object_storage_api import VPSAObjectStorageApi  # noqa: E501
from CommandCenter.rest import ApiException


class TestVPSAObjectStorageApi(unittest.TestCase):
    """VPSAObjectStorageApi unit test stubs"""

    def setUp(self):
        self.api = CommandCenter.api.vpsa_object_storage_api.VPSAObjectStorageApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_drives_to_zios(self):
        """Test case for add_drives_to_zios

        """
        pass

    def test_add_proxy_virtual_controller_zios(self):
        """Test case for add_proxy_virtual_controller_zios

        """
        pass

    def test_add_virtual_nets_to_zios(self):
        """Test case for add_virtual_nets_to_zios

        """
        pass

    def test_add_zios_endpoints_configs_for_upload_types(self):
        """Test case for add_zios_endpoints_configs_for_upload_types

        """
        pass

    def test_assign_public_ip_zios(self):
        """Test case for assign_public_ip_zios

        """
        pass

    def test_change_engine_type_zios(self):
        """Test case for change_engine_type_zios

        """
        pass

    def test_continue_policy_rebalance_zios(self):
        """Test case for continue_policy_rebalance_zios

        """
        pass

    def test_create_storage_policy_zios(self):
        """Test case for create_storage_policy_zios

        """
        pass

    def test_create_zios_endpoints_configs_for_upload_types(self):
        """Test case for create_zios_endpoints_configs_for_upload_types

        """
        pass

    def test_create_zios_upload_endpoint(self):
        """Test case for create_zios_upload_endpoint

        """
        pass

    def test_create_zsnap_zios(self):
        """Test case for create_zsnap_zios

        """
        pass

    def test_delete_zios_endpoints_config_for_upload_types(self):
        """Test case for delete_zios_endpoints_config_for_upload_types

        """
        pass

    def test_delete_zios_upload_endpoint(self):
        """Test case for delete_zios_upload_endpoint

        """
        pass

    def test_disable_elastic_load_balancer_zios(self):
        """Test case for disable_elastic_load_balancer_zios

        """
        pass

    def test_enable_elastic_load_balancer_zios(self):
        """Test case for enable_elastic_load_balancer_zios

        """
        pass

    def test_get_all_vpsaos(self):
        """Test case for get_all_vpsaos

        """
        pass

    def test_get_all_zios_drives_from_cc(self):
        """Test case for get_all_zios_drives_from_cc

        """
        pass

    def test_get_load_balancer(self):
        """Test case for get_load_balancer

        """
        pass

    def test_get_vpsaos_accounts(self):
        """Test case for get_vpsaos_accounts

        """
        pass

    def test_get_vpsaos_comments(self):
        """Test case for get_vpsaos_comments

        """
        pass

    def test_get_vpsaos_sps(self):
        """Test case for get_vpsaos_sps

        """
        pass

    def test_get_vpsaos_vcs(self):
        """Test case for get_vpsaos_vcs

        """
        pass

    def test_get_zios_from_cloud(self):
        """Test case for get_zios_from_cloud

        """
        pass

    def test_get_zios_upload_endpoints(self):
        """Test case for get_zios_upload_endpoints

        """
        pass

    def test_hibernate_zios(self):
        """Test case for hibernate_zios

        """
        pass

    def test_list_availiables_virtual_net_to_add_vpsa(self):
        """Test case for list_availiables_virtual_net_to_add_vpsa

        """
        pass

    def test_list_vpsa_virtual_nets(self):
        """Test case for list_vpsa_virtual_nets

        """
        pass

    def test_list_zios_endpoints_configs_by_upload_types(self):
        """Test case for list_zios_endpoints_configs_by_upload_types

        """
        pass

    def test_maintenance_mode(self):
        """Test case for maintenance_mode

        """
        pass

    def test_pause_policy_rebalance_zios(self):
        """Test case for pause_policy_rebalance_zios

        """
        pass

    def test_remove_virtual_nets_from_zios(self):
        """Test case for remove_virtual_nets_from_zios

        """
        pass

    def test_restore_zios(self):
        """Test case for restore_zios

        """
        pass

    def test_unassign_public_ip_zios(self):
        """Test case for unassign_public_ip_zios

        """
        pass

    def test_update_zios_upload_endpoint(self):
        """Test case for update_zios_upload_endpoint

        """
        pass

    def test_upgrade_zios(self):
        """Test case for upgrade_zios

        """
        pass


if __name__ == '__main__':
    unittest.main()
