# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import CommandCenter
from CommandCenter.models.inline_response200135_vcs import InlineResponse200135Vcs  # noqa: E501
from CommandCenter.rest import ApiException


class TestInlineResponse200135Vcs(unittest.TestCase):
    """InlineResponse200135Vcs unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testInlineResponse200135Vcs(self):
        """Test InlineResponse200135Vcs"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CommandCenter.models.inline_response200135_vcs.InlineResponse200135Vcs()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
