# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class InlineResponse20035Logs(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'title': 'str',
        'time': 'str',
        'severity': 'str',
        'source_type': 'str',
        'source_name': 'str'
    }

    attribute_map = {
        'id': 'id',
        'title': 'title',
        'time': 'time',
        'severity': 'severity',
        'source_type': 'source_type',
        'source_name': 'source_name'
    }

    def __init__(self, id=None, title=None, time=None, severity=None, source_type=None, source_name=None, _configuration=None):  # noqa: E501
        """InlineResponse20035Logs - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._title = None
        self._time = None
        self._severity = None
        self._source_type = None
        self._source_name = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if title is not None:
            self.title = title
        if time is not None:
            self.time = time
        if severity is not None:
            self.severity = severity
        if source_type is not None:
            self.source_type = source_type
        if source_name is not None:
            self.source_name = source_name

    @property
    def id(self):
        """Gets the id of this InlineResponse20035Logs.  # noqa: E501


        :return: The id of this InlineResponse20035Logs.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InlineResponse20035Logs.


        :param id: The id of this InlineResponse20035Logs.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def title(self):
        """Gets the title of this InlineResponse20035Logs.  # noqa: E501


        :return: The title of this InlineResponse20035Logs.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this InlineResponse20035Logs.


        :param title: The title of this InlineResponse20035Logs.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def time(self):
        """Gets the time of this InlineResponse20035Logs.  # noqa: E501


        :return: The time of this InlineResponse20035Logs.  # noqa: E501
        :rtype: str
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this InlineResponse20035Logs.


        :param time: The time of this InlineResponse20035Logs.  # noqa: E501
        :type: str
        """

        self._time = time

    @property
    def severity(self):
        """Gets the severity of this InlineResponse20035Logs.  # noqa: E501


        :return: The severity of this InlineResponse20035Logs.  # noqa: E501
        :rtype: str
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """Sets the severity of this InlineResponse20035Logs.


        :param severity: The severity of this InlineResponse20035Logs.  # noqa: E501
        :type: str
        """

        self._severity = severity

    @property
    def source_type(self):
        """Gets the source_type of this InlineResponse20035Logs.  # noqa: E501


        :return: The source_type of this InlineResponse20035Logs.  # noqa: E501
        :rtype: str
        """
        return self._source_type

    @source_type.setter
    def source_type(self, source_type):
        """Sets the source_type of this InlineResponse20035Logs.


        :param source_type: The source_type of this InlineResponse20035Logs.  # noqa: E501
        :type: str
        """

        self._source_type = source_type

    @property
    def source_name(self):
        """Gets the source_name of this InlineResponse20035Logs.  # noqa: E501


        :return: The source_name of this InlineResponse20035Logs.  # noqa: E501
        :rtype: str
        """
        return self._source_name

    @source_name.setter
    def source_name(self, source_name):
        """Sets the source_name of this InlineResponse20035Logs.


        :param source_name: The source_name of this InlineResponse20035Logs.  # noqa: E501
        :type: str
        """

        self._source_name = source_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20035Logs, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20035Logs):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20035Logs):
            return True

        return self.to_dict() != other.to_dict()
