# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import CommandCenter
from CommandCenter.api.cloud_settings_api import CloudSettingsApi  # noqa: E501
from CommandCenter.rest import ApiException


class TestCloudSettingsApi(unittest.TestCase):
    """CloudSettingsApi unit test stubs"""

    def setUp(self):
        self.api = CommandCenter.api.cloud_settings_api.CloudSettingsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_cloud_control_ip_whitelisting_entries(self):
        """Test case for add_cloud_control_ip_whitelisting_entries

        """
        pass

    def test_create_endpoint(self):
        """Test case for create_endpoint

        """
        pass

    def test_create_endpoints_config(self):
        """Test case for create_endpoints_config

        """
        pass

    def test_delete_cloud_control_ip_whitelisting_entries(self):
        """Test case for delete_cloud_control_ip_whitelisting_entries

        """
        pass

    def test_delete_endpoint(self):
        """Test case for delete_endpoint

        """
        pass

    def test_delete_endpoints_config(self):
        """Test case for delete_endpoints_config

        """
        pass

    def test_delete_ticket_settings(self):
        """Test case for delete_ticket_settings

        """
        pass

    def test_disable_cloud_control_ip_whitelisting(self):
        """Test case for disable_cloud_control_ip_whitelisting

        """
        pass

    def test_enable_cloud_control_ip_whitelisting(self):
        """Test case for enable_cloud_control_ip_whitelisting

        """
        pass

    def test_get_cloud_control_ip_whitelist_entries(self):
        """Test case for get_cloud_control_ip_whitelist_entries

        """
        pass

    def test_get_cloud_control_ip_whitelist_status(self):
        """Test case for get_cloud_control_ip_whitelist_status

        """
        pass

    def test_get_cloud_settings(self):
        """Test case for get_cloud_settings

        """
        pass

    def test_get_endpoints(self):
        """Test case for get_endpoints

        """
        pass

    def test_get_endpoints_config(self):
        """Test case for get_endpoints_config

        """
        pass

    def test_get_log_level(self):
        """Test case for get_log_level

        """
        pass

    def test_get_remote_support_access(self):
        """Test case for get_remote_support_access

        """
        pass

    def test_get_tickets_settings(self):
        """Test case for get_tickets_settings

        """
        pass

    def test_set_automatic_drive_replacement(self):
        """Test case for set_automatic_drive_replacement

        """
        pass

    def test_set_ccvm_cert(self):
        """Test case for set_ccvm_cert

        """
        pass

    def test_set_ccvm_default_engine(self):
        """Test case for set_ccvm_default_engine

        """
        pass

    def test_set_mount_capacity_alert_threshold(self):
        """Test case for set_mount_capacity_alert_threshold

        """
        pass

    def test_set_remote_region_backend_protocol(self):
        """Test case for set_remote_region_backend_protocol

        """
        pass

    def test_set_remote_support_access(self):
        """Test case for set_remote_support_access

        """
        pass

    def test_set_snmp(self):
        """Test case for set_snmp

        """
        pass

    def test_set_ticket_settings(self):
        """Test case for set_ticket_settings

        """
        pass

    def test_set_vpsa_cert(self):
        """Test case for set_vpsa_cert

        """
        pass

    def test_set_vpsa_recycle_bin(self):
        """Test case for set_vpsa_recycle_bin

        """
        pass

    def test_set_zadara_cert(self):
        """Test case for set_zadara_cert

        """
        pass

    def test_update_cloud_control_ip_whitelisting_entries(self):
        """Test case for update_cloud_control_ip_whitelisting_entries

        """
        pass

    def test_update_endpoint(self):
        """Test case for update_endpoint

        """
        pass

    def test_update_endpoints_config(self):
        """Test case for update_endpoints_config

        """
        pass


if __name__ == '__main__':
    unittest.main()
