# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class InlineResponse20026ResponseDisks(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'display_name': 'str',
        'disk_type': 'str',
        'disk_uuid': 'str',
        'storage_node': 'str',
        'vpartition_id': 'int',
        'raid_group_name': 'str',
        'usage': 'str',
        'status': 'str',
        'capacity': 'int',
        'allocation_group': 'str',
        'cache': 'str',
        'created_at': 'str',
        'modified_at': 'str'
    }

    attribute_map = {
        'name': 'name',
        'display_name': 'display_name',
        'disk_type': 'disk_type',
        'disk_uuid': 'disk_uuid',
        'storage_node': 'storage_node',
        'vpartition_id': 'vpartition_id',
        'raid_group_name': 'raid_group_name',
        'usage': 'usage',
        'status': 'status',
        'capacity': 'capacity',
        'allocation_group': 'allocation_group',
        'cache': 'cache',
        'created_at': 'created_at',
        'modified_at': 'modified_at'
    }

    def __init__(self, name=None, display_name=None, disk_type=None, disk_uuid=None, storage_node=None, vpartition_id=None, raid_group_name=None, usage=None, status=None, capacity=None, allocation_group=None, cache=None, created_at=None, modified_at=None, _configuration=None):  # noqa: E501
        """InlineResponse20026ResponseDisks - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._display_name = None
        self._disk_type = None
        self._disk_uuid = None
        self._storage_node = None
        self._vpartition_id = None
        self._raid_group_name = None
        self._usage = None
        self._status = None
        self._capacity = None
        self._allocation_group = None
        self._cache = None
        self._created_at = None
        self._modified_at = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if display_name is not None:
            self.display_name = display_name
        if disk_type is not None:
            self.disk_type = disk_type
        if disk_uuid is not None:
            self.disk_uuid = disk_uuid
        if storage_node is not None:
            self.storage_node = storage_node
        if vpartition_id is not None:
            self.vpartition_id = vpartition_id
        if raid_group_name is not None:
            self.raid_group_name = raid_group_name
        if usage is not None:
            self.usage = usage
        if status is not None:
            self.status = status
        if capacity is not None:
            self.capacity = capacity
        if allocation_group is not None:
            self.allocation_group = allocation_group
        if cache is not None:
            self.cache = cache
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at

    @property
    def name(self):
        """Gets the name of this InlineResponse20026ResponseDisks.  # noqa: E501


        :return: The name of this InlineResponse20026ResponseDisks.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse20026ResponseDisks.


        :param name: The name of this InlineResponse20026ResponseDisks.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def display_name(self):
        """Gets the display_name of this InlineResponse20026ResponseDisks.  # noqa: E501


        :return: The display_name of this InlineResponse20026ResponseDisks.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this InlineResponse20026ResponseDisks.


        :param display_name: The display_name of this InlineResponse20026ResponseDisks.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def disk_type(self):
        """Gets the disk_type of this InlineResponse20026ResponseDisks.  # noqa: E501


        :return: The disk_type of this InlineResponse20026ResponseDisks.  # noqa: E501
        :rtype: str
        """
        return self._disk_type

    @disk_type.setter
    def disk_type(self, disk_type):
        """Sets the disk_type of this InlineResponse20026ResponseDisks.


        :param disk_type: The disk_type of this InlineResponse20026ResponseDisks.  # noqa: E501
        :type: str
        """

        self._disk_type = disk_type

    @property
    def disk_uuid(self):
        """Gets the disk_uuid of this InlineResponse20026ResponseDisks.  # noqa: E501


        :return: The disk_uuid of this InlineResponse20026ResponseDisks.  # noqa: E501
        :rtype: str
        """
        return self._disk_uuid

    @disk_uuid.setter
    def disk_uuid(self, disk_uuid):
        """Sets the disk_uuid of this InlineResponse20026ResponseDisks.


        :param disk_uuid: The disk_uuid of this InlineResponse20026ResponseDisks.  # noqa: E501
        :type: str
        """

        self._disk_uuid = disk_uuid

    @property
    def storage_node(self):
        """Gets the storage_node of this InlineResponse20026ResponseDisks.  # noqa: E501


        :return: The storage_node of this InlineResponse20026ResponseDisks.  # noqa: E501
        :rtype: str
        """
        return self._storage_node

    @storage_node.setter
    def storage_node(self, storage_node):
        """Sets the storage_node of this InlineResponse20026ResponseDisks.


        :param storage_node: The storage_node of this InlineResponse20026ResponseDisks.  # noqa: E501
        :type: str
        """

        self._storage_node = storage_node

    @property
    def vpartition_id(self):
        """Gets the vpartition_id of this InlineResponse20026ResponseDisks.  # noqa: E501


        :return: The vpartition_id of this InlineResponse20026ResponseDisks.  # noqa: E501
        :rtype: int
        """
        return self._vpartition_id

    @vpartition_id.setter
    def vpartition_id(self, vpartition_id):
        """Sets the vpartition_id of this InlineResponse20026ResponseDisks.


        :param vpartition_id: The vpartition_id of this InlineResponse20026ResponseDisks.  # noqa: E501
        :type: int
        """

        self._vpartition_id = vpartition_id

    @property
    def raid_group_name(self):
        """Gets the raid_group_name of this InlineResponse20026ResponseDisks.  # noqa: E501


        :return: The raid_group_name of this InlineResponse20026ResponseDisks.  # noqa: E501
        :rtype: str
        """
        return self._raid_group_name

    @raid_group_name.setter
    def raid_group_name(self, raid_group_name):
        """Sets the raid_group_name of this InlineResponse20026ResponseDisks.


        :param raid_group_name: The raid_group_name of this InlineResponse20026ResponseDisks.  # noqa: E501
        :type: str
        """

        self._raid_group_name = raid_group_name

    @property
    def usage(self):
        """Gets the usage of this InlineResponse20026ResponseDisks.  # noqa: E501


        :return: The usage of this InlineResponse20026ResponseDisks.  # noqa: E501
        :rtype: str
        """
        return self._usage

    @usage.setter
    def usage(self, usage):
        """Sets the usage of this InlineResponse20026ResponseDisks.


        :param usage: The usage of this InlineResponse20026ResponseDisks.  # noqa: E501
        :type: str
        """

        self._usage = usage

    @property
    def status(self):
        """Gets the status of this InlineResponse20026ResponseDisks.  # noqa: E501


        :return: The status of this InlineResponse20026ResponseDisks.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InlineResponse20026ResponseDisks.


        :param status: The status of this InlineResponse20026ResponseDisks.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def capacity(self):
        """Gets the capacity of this InlineResponse20026ResponseDisks.  # noqa: E501


        :return: The capacity of this InlineResponse20026ResponseDisks.  # noqa: E501
        :rtype: int
        """
        return self._capacity

    @capacity.setter
    def capacity(self, capacity):
        """Sets the capacity of this InlineResponse20026ResponseDisks.


        :param capacity: The capacity of this InlineResponse20026ResponseDisks.  # noqa: E501
        :type: int
        """

        self._capacity = capacity

    @property
    def allocation_group(self):
        """Gets the allocation_group of this InlineResponse20026ResponseDisks.  # noqa: E501


        :return: The allocation_group of this InlineResponse20026ResponseDisks.  # noqa: E501
        :rtype: str
        """
        return self._allocation_group

    @allocation_group.setter
    def allocation_group(self, allocation_group):
        """Sets the allocation_group of this InlineResponse20026ResponseDisks.


        :param allocation_group: The allocation_group of this InlineResponse20026ResponseDisks.  # noqa: E501
        :type: str
        """

        self._allocation_group = allocation_group

    @property
    def cache(self):
        """Gets the cache of this InlineResponse20026ResponseDisks.  # noqa: E501


        :return: The cache of this InlineResponse20026ResponseDisks.  # noqa: E501
        :rtype: str
        """
        return self._cache

    @cache.setter
    def cache(self, cache):
        """Sets the cache of this InlineResponse20026ResponseDisks.


        :param cache: The cache of this InlineResponse20026ResponseDisks.  # noqa: E501
        :type: str
        """

        self._cache = cache

    @property
    def created_at(self):
        """Gets the created_at of this InlineResponse20026ResponseDisks.  # noqa: E501


        :return: The created_at of this InlineResponse20026ResponseDisks.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this InlineResponse20026ResponseDisks.


        :param created_at: The created_at of this InlineResponse20026ResponseDisks.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this InlineResponse20026ResponseDisks.  # noqa: E501


        :return: The modified_at of this InlineResponse20026ResponseDisks.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this InlineResponse20026ResponseDisks.


        :param modified_at: The modified_at of this InlineResponse20026ResponseDisks.  # noqa: E501
        :type: str
        """

        self._modified_at = modified_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20026ResponseDisks, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20026ResponseDisks):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20026ResponseDisks):
            return True

        return self.to_dict() != other.to_dict()
