# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import CommandCenter
from CommandCenter.api.storage_nodes_api import StorageNodesApi  # noqa: E501
from CommandCenter.rest import ApiException


class TestStorageNodesApi(unittest.TestCase):
    """StorageNodesApi unit test stubs"""

    def setUp(self):
        self.api = CommandCenter.api.storage_nodes_api.StorageNodesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_evacoate_vc_from_sn(self):
        """Test case for evacoate_vc_from_sn

        """
        pass

    def test_evacoated_drives_from_sn(self):
        """Test case for evacoated_drives_from_sn

        """
        pass

    def test_get_all_storage_nodes(self):
        """Test case for get_all_storage_nodes

        """
        pass

    def test_get_schedulable_services_status(self):
        """Test case for get_schedulable_services_status

        """
        pass

    def test_get_sn_cache_partitions_details(self):
        """Test case for get_sn_cache_partitions_details

        """
        pass

    def test_get_sn_conf(self):
        """Test case for get_sn_conf

        """
        pass

    def test_get_sn_vcs_details(self):
        """Test case for get_sn_vcs_details

        """
        pass

    def test_get_storage_node(self):
        """Test case for get_storage_node

        """
        pass

    def test_get_storage_node_drives(self):
        """Test case for get_storage_node_drives

        """
        pass

    def test_import_sn_new_drives(self):
        """Test case for import_sn_new_drives

        """
        pass

    def test_install_sn(self):
        """Test case for install_sn

        """
        pass

    def test_license_storage_node(self):
        """Test case for license_storage_node

        """
        pass

    def test_reboot_storage_node(self):
        """Test case for reboot_storage_node

        """
        pass

    def test_refresh_sn_license_status(self):
        """Test case for refresh_sn_license_status

        """
        pass

    def test_set_scheduling_status(self):
        """Test case for set_scheduling_status

        """
        pass

    def test_shutdown_storage_node(self):
        """Test case for shutdown_storage_node

        """
        pass

    def test_upgrade_sn(self):
        """Test case for upgrade_sn

        """
        pass

    def test_upgrade_sn_megaraid_and_drives_firmware(self):
        """Test case for upgrade_sn_megaraid_and_drives_firmware

        """
        pass

    def test_zsnap_storage_node(self):
        """Test case for zsnap_storage_node

        """
        pass


if __name__ == '__main__':
    unittest.main()
