# coding: utf-8

"""
    Zadara VPSA Object Storage REST API

    # Overview  This document outlines the methods available for administrating your VPSA&#174; Object Storage. The API supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or through the X-Access-Key header. Alternately, you can use the username and password parameters for authentication, but we do not recommend this method for anything other than possibly retrieving an API key.  By default , all operations are allowed only to VPSA Object Storage admin. Some actions are allowed by an account admin and they will be marked on the action's header  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some time to complete. When using the API, this can cause some actions, such as adding drives to storage policy, to be undesirably asynchronous. You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Metering API  Metering information can be retrieved using the VPSA Object Storage API for the following components:  - Accounts - Users - Drives - Virtual Controllers - Load Balancer Groups - Storage Policies  Metering information returned by the API is subject to the following constraints:  - 10 seconds interval - 1 hour range - 1 minute interval - 1 day range - 1 hour interval - 30 days range  Values outside the accepted range will be returned as 0.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Zios.configuration import Configuration


class CreateAccountRequests(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'request_action': 'str',
        'arguments': 'object'
    }

    attribute_map = {
        'request_action': 'request_action',
        'arguments': 'arguments'
    }

    def __init__(self, request_action=None, arguments=None, _configuration=None):  # noqa: E501
        """CreateAccountRequests - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._request_action = None
        self._arguments = None
        self.discriminator = None

        self.request_action = request_action
        self.arguments = arguments

    @property
    def request_action(self):
        """Gets the request_action of this CreateAccountRequests.  # noqa: E501


        :return: The request_action of this CreateAccountRequests.  # noqa: E501
        :rtype: str
        """
        return self._request_action

    @request_action.setter
    def request_action(self, request_action):
        """Sets the request_action of this CreateAccountRequests.


        :param request_action: The request_action of this CreateAccountRequests.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and request_action is None:
            raise ValueError("Invalid value for `request_action`, must not be `None`")  # noqa: E501
        allowed_values = ["register_account"]  # noqa: E501
        if (self._configuration.client_side_validation and
                request_action not in allowed_values):
            raise ValueError(
                "Invalid value for `request_action` ({0}), must be one of {1}"  # noqa: E501
                .format(request_action, allowed_values)
            )

        self._request_action = request_action

    @property
    def arguments(self):
        """Gets the arguments of this CreateAccountRequests.  # noqa: E501

        Object containing username, account, email and password.  # noqa: E501

        :return: The arguments of this CreateAccountRequests.  # noqa: E501
        :rtype: object
        """
        return self._arguments

    @arguments.setter
    def arguments(self, arguments):
        """Sets the arguments of this CreateAccountRequests.

        Object containing username, account, email and password.  # noqa: E501

        :param arguments: The arguments of this CreateAccountRequests.  # noqa: E501
        :type: object
        """
        if self._configuration.client_side_validation and arguments is None:
            raise ValueError("Invalid value for `arguments`, must not be `None`")  # noqa: E501

        self._arguments = arguments

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateAccountRequests, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateAccountRequests):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateAccountRequests):
            return True

        return self.to_dict() != other.to_dict()
