# coding: utf-8

"""
    Zadara Provisioning Portal API

     # Overview  This document outlines the methods available for creation and high-level administration of Zadara Storage VPSAs via a Zadara Storage Provisioning Portal. This API supports form-encoded requests, and can return either JSON or XML responses.  ## Endpoint  The base URL for the requests is the Provisioning Portal URL you created your VPSA through - for example: https://manage.zadarastorage.com/, and all APIs will be prefixed with /api as noted in the documentation below.  ## Authentication  To use this API, an authentication token is required. The API for retrieving this token can be found below in the Authentication section. You may pass this token in requests either via the the X-Token header or via basic authentication (base64 encoded) in Authorization header.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from ProvisioningPortal.configuration import Configuration


class InlineResponse2001Cache(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'base_cache_gb': 'int',
        'max_flash_cache_gb': 'int',
        'recommended_flash_cache_gb': 'int'
    }

    attribute_map = {
        'base_cache_gb': 'base_cache_gb',
        'max_flash_cache_gb': 'max_flash_cache_gb',
        'recommended_flash_cache_gb': 'recommended_flash_cache_gb'
    }

    def __init__(self, base_cache_gb=None, max_flash_cache_gb=None, recommended_flash_cache_gb=None, _configuration=None):  # noqa: E501
        """InlineResponse2001Cache - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._base_cache_gb = None
        self._max_flash_cache_gb = None
        self._recommended_flash_cache_gb = None
        self.discriminator = None

        if base_cache_gb is not None:
            self.base_cache_gb = base_cache_gb
        if max_flash_cache_gb is not None:
            self.max_flash_cache_gb = max_flash_cache_gb
        if recommended_flash_cache_gb is not None:
            self.recommended_flash_cache_gb = recommended_flash_cache_gb

    @property
    def base_cache_gb(self):
        """Gets the base_cache_gb of this InlineResponse2001Cache.  # noqa: E501


        :return: The base_cache_gb of this InlineResponse2001Cache.  # noqa: E501
        :rtype: int
        """
        return self._base_cache_gb

    @base_cache_gb.setter
    def base_cache_gb(self, base_cache_gb):
        """Sets the base_cache_gb of this InlineResponse2001Cache.


        :param base_cache_gb: The base_cache_gb of this InlineResponse2001Cache.  # noqa: E501
        :type: int
        """

        self._base_cache_gb = base_cache_gb

    @property
    def max_flash_cache_gb(self):
        """Gets the max_flash_cache_gb of this InlineResponse2001Cache.  # noqa: E501


        :return: The max_flash_cache_gb of this InlineResponse2001Cache.  # noqa: E501
        :rtype: int
        """
        return self._max_flash_cache_gb

    @max_flash_cache_gb.setter
    def max_flash_cache_gb(self, max_flash_cache_gb):
        """Sets the max_flash_cache_gb of this InlineResponse2001Cache.


        :param max_flash_cache_gb: The max_flash_cache_gb of this InlineResponse2001Cache.  # noqa: E501
        :type: int
        """

        self._max_flash_cache_gb = max_flash_cache_gb

    @property
    def recommended_flash_cache_gb(self):
        """Gets the recommended_flash_cache_gb of this InlineResponse2001Cache.  # noqa: E501


        :return: The recommended_flash_cache_gb of this InlineResponse2001Cache.  # noqa: E501
        :rtype: int
        """
        return self._recommended_flash_cache_gb

    @recommended_flash_cache_gb.setter
    def recommended_flash_cache_gb(self, recommended_flash_cache_gb):
        """Sets the recommended_flash_cache_gb of this InlineResponse2001Cache.


        :param recommended_flash_cache_gb: The recommended_flash_cache_gb of this InlineResponse2001Cache.  # noqa: E501
        :type: int
        """

        self._recommended_flash_cache_gb = recommended_flash_cache_gb

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse2001Cache, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse2001Cache):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse2001Cache):
            return True

        return self.to_dict() != other.to_dict()
