# coding: utf-8

"""
    Zadara Provisioning Portal API

     # Overview  This document outlines the methods available for creation and high-level administration of Zadara Storage VPSAs via a Zadara Storage Provisioning Portal. This API supports form-encoded requests, and can return either JSON or XML responses.  ## Endpoint  The base URL for the requests is the Provisioning Portal URL you created your VPSA through - for example: https://manage.zadarastorage.com/, and all APIs will be prefixed with /api as noted in the documentation below.  ## Authentication  To use this API, an authentication token is required. The API for retrieving this token can be found below in the Authentication section. You may pass this token in requests either via the the X-Token header or via basic authentication (base64 encoded) in Authorization header.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from ProvisioningPortal.configuration import Configuration


class InlineResponse20026Data(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'status': 'str',
        'vpsa_request_id': 'int',
        'allocation_zones': 'list[str]',
        'engine': 'InlineResponse20025Engine',
        'description': 'str',
        'management_url': 'str',
        'initial_passcode': 'str',
        'drive_count': 'int',
        'ip_address': 'str',
        'id': 'str',
        'time_created_gmt': 'str',
        'name': 'str',
        'cache': 'InlineResponse20026DataCache',
        'version': 'str',
        'locked_down': 'int',
        'provider': 'InlineResponse20025Provider'
    }

    attribute_map = {
        'status': 'status',
        'vpsa_request_id': 'vpsa_request_id',
        'allocation_zones': 'allocation_zones',
        'engine': 'engine',
        'description': 'description',
        'management_url': 'management_url',
        'initial_passcode': 'initial_passcode',
        'drive_count': 'drive_count',
        'ip_address': 'ip_address',
        'id': 'id',
        'time_created_gmt': 'time_created_gmt',
        'name': 'name',
        'cache': 'cache',
        'version': 'version',
        'locked_down': 'locked_down',
        'provider': 'provider'
    }

    def __init__(self, status=None, vpsa_request_id=None, allocation_zones=None, engine=None, description=None, management_url=None, initial_passcode=None, drive_count=None, ip_address=None, id=None, time_created_gmt=None, name=None, cache=None, version=None, locked_down=None, provider=None, _configuration=None):  # noqa: E501
        """InlineResponse20026Data - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._status = None
        self._vpsa_request_id = None
        self._allocation_zones = None
        self._engine = None
        self._description = None
        self._management_url = None
        self._initial_passcode = None
        self._drive_count = None
        self._ip_address = None
        self._id = None
        self._time_created_gmt = None
        self._name = None
        self._cache = None
        self._version = None
        self._locked_down = None
        self._provider = None
        self.discriminator = None

        if status is not None:
            self.status = status
        if vpsa_request_id is not None:
            self.vpsa_request_id = vpsa_request_id
        if allocation_zones is not None:
            self.allocation_zones = allocation_zones
        if engine is not None:
            self.engine = engine
        if description is not None:
            self.description = description
        if management_url is not None:
            self.management_url = management_url
        if initial_passcode is not None:
            self.initial_passcode = initial_passcode
        if drive_count is not None:
            self.drive_count = drive_count
        if ip_address is not None:
            self.ip_address = ip_address
        if id is not None:
            self.id = id
        if time_created_gmt is not None:
            self.time_created_gmt = time_created_gmt
        if name is not None:
            self.name = name
        if cache is not None:
            self.cache = cache
        if version is not None:
            self.version = version
        if locked_down is not None:
            self.locked_down = locked_down
        if provider is not None:
            self.provider = provider

    @property
    def status(self):
        """Gets the status of this InlineResponse20026Data.  # noqa: E501


        :return: The status of this InlineResponse20026Data.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InlineResponse20026Data.


        :param status: The status of this InlineResponse20026Data.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def vpsa_request_id(self):
        """Gets the vpsa_request_id of this InlineResponse20026Data.  # noqa: E501

        When VPSA creation is moderated, this is the creation request ID.  # noqa: E501

        :return: The vpsa_request_id of this InlineResponse20026Data.  # noqa: E501
        :rtype: int
        """
        return self._vpsa_request_id

    @vpsa_request_id.setter
    def vpsa_request_id(self, vpsa_request_id):
        """Sets the vpsa_request_id of this InlineResponse20026Data.

        When VPSA creation is moderated, this is the creation request ID.  # noqa: E501

        :param vpsa_request_id: The vpsa_request_id of this InlineResponse20026Data.  # noqa: E501
        :type: int
        """

        self._vpsa_request_id = vpsa_request_id

    @property
    def allocation_zones(self):
        """Gets the allocation_zones of this InlineResponse20026Data.  # noqa: E501


        :return: The allocation_zones of this InlineResponse20026Data.  # noqa: E501
        :rtype: list[str]
        """
        return self._allocation_zones

    @allocation_zones.setter
    def allocation_zones(self, allocation_zones):
        """Sets the allocation_zones of this InlineResponse20026Data.


        :param allocation_zones: The allocation_zones of this InlineResponse20026Data.  # noqa: E501
        :type: list[str]
        """

        self._allocation_zones = allocation_zones

    @property
    def engine(self):
        """Gets the engine of this InlineResponse20026Data.  # noqa: E501


        :return: The engine of this InlineResponse20026Data.  # noqa: E501
        :rtype: InlineResponse20025Engine
        """
        return self._engine

    @engine.setter
    def engine(self, engine):
        """Sets the engine of this InlineResponse20026Data.


        :param engine: The engine of this InlineResponse20026Data.  # noqa: E501
        :type: InlineResponse20025Engine
        """

        self._engine = engine

    @property
    def description(self):
        """Gets the description of this InlineResponse20026Data.  # noqa: E501


        :return: The description of this InlineResponse20026Data.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this InlineResponse20026Data.


        :param description: The description of this InlineResponse20026Data.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def management_url(self):
        """Gets the management_url of this InlineResponse20026Data.  # noqa: E501


        :return: The management_url of this InlineResponse20026Data.  # noqa: E501
        :rtype: str
        """
        return self._management_url

    @management_url.setter
    def management_url(self, management_url):
        """Sets the management_url of this InlineResponse20026Data.


        :param management_url: The management_url of this InlineResponse20026Data.  # noqa: E501
        :type: str
        """

        self._management_url = management_url

    @property
    def initial_passcode(self):
        """Gets the initial_passcode of this InlineResponse20026Data.  # noqa: E501


        :return: The initial_passcode of this InlineResponse20026Data.  # noqa: E501
        :rtype: str
        """
        return self._initial_passcode

    @initial_passcode.setter
    def initial_passcode(self, initial_passcode):
        """Sets the initial_passcode of this InlineResponse20026Data.


        :param initial_passcode: The initial_passcode of this InlineResponse20026Data.  # noqa: E501
        :type: str
        """

        self._initial_passcode = initial_passcode

    @property
    def drive_count(self):
        """Gets the drive_count of this InlineResponse20026Data.  # noqa: E501


        :return: The drive_count of this InlineResponse20026Data.  # noqa: E501
        :rtype: int
        """
        return self._drive_count

    @drive_count.setter
    def drive_count(self, drive_count):
        """Sets the drive_count of this InlineResponse20026Data.


        :param drive_count: The drive_count of this InlineResponse20026Data.  # noqa: E501
        :type: int
        """

        self._drive_count = drive_count

    @property
    def ip_address(self):
        """Gets the ip_address of this InlineResponse20026Data.  # noqa: E501


        :return: The ip_address of this InlineResponse20026Data.  # noqa: E501
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """Sets the ip_address of this InlineResponse20026Data.


        :param ip_address: The ip_address of this InlineResponse20026Data.  # noqa: E501
        :type: str
        """

        self._ip_address = ip_address

    @property
    def id(self):
        """Gets the id of this InlineResponse20026Data.  # noqa: E501


        :return: The id of this InlineResponse20026Data.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InlineResponse20026Data.


        :param id: The id of this InlineResponse20026Data.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def time_created_gmt(self):
        """Gets the time_created_gmt of this InlineResponse20026Data.  # noqa: E501


        :return: The time_created_gmt of this InlineResponse20026Data.  # noqa: E501
        :rtype: str
        """
        return self._time_created_gmt

    @time_created_gmt.setter
    def time_created_gmt(self, time_created_gmt):
        """Sets the time_created_gmt of this InlineResponse20026Data.


        :param time_created_gmt: The time_created_gmt of this InlineResponse20026Data.  # noqa: E501
        :type: str
        """

        self._time_created_gmt = time_created_gmt

    @property
    def name(self):
        """Gets the name of this InlineResponse20026Data.  # noqa: E501


        :return: The name of this InlineResponse20026Data.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse20026Data.


        :param name: The name of this InlineResponse20026Data.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def cache(self):
        """Gets the cache of this InlineResponse20026Data.  # noqa: E501


        :return: The cache of this InlineResponse20026Data.  # noqa: E501
        :rtype: InlineResponse20026DataCache
        """
        return self._cache

    @cache.setter
    def cache(self, cache):
        """Sets the cache of this InlineResponse20026Data.


        :param cache: The cache of this InlineResponse20026Data.  # noqa: E501
        :type: InlineResponse20026DataCache
        """

        self._cache = cache

    @property
    def version(self):
        """Gets the version of this InlineResponse20026Data.  # noqa: E501


        :return: The version of this InlineResponse20026Data.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this InlineResponse20026Data.


        :param version: The version of this InlineResponse20026Data.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def locked_down(self):
        """Gets the locked_down of this InlineResponse20026Data.  # noqa: E501


        :return: The locked_down of this InlineResponse20026Data.  # noqa: E501
        :rtype: int
        """
        return self._locked_down

    @locked_down.setter
    def locked_down(self, locked_down):
        """Sets the locked_down of this InlineResponse20026Data.


        :param locked_down: The locked_down of this InlineResponse20026Data.  # noqa: E501
        :type: int
        """

        self._locked_down = locked_down

    @property
    def provider(self):
        """Gets the provider of this InlineResponse20026Data.  # noqa: E501


        :return: The provider of this InlineResponse20026Data.  # noqa: E501
        :rtype: InlineResponse20025Provider
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """Sets the provider of this InlineResponse20026Data.


        :param provider: The provider of this InlineResponse20026Data.  # noqa: E501
        :type: InlineResponse20025Provider
        """

        self._provider = provider

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20026Data, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20026Data):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20026Data):
            return True

        return self.to_dict() != other.to_dict()
