# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class AttachServersToVolume(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'volume_name': 'str',
        'access_type': 'str',
        'lun': 'int',
        'readonly': 'str',
        'force': 'str'
    }

    attribute_map = {
        'volume_name': 'volume_name',
        'access_type': 'access_type',
        'lun': 'lun',
        'readonly': 'readonly',
        'force': 'force'
    }

    def __init__(self, volume_name=None, access_type=None, lun=None, readonly=None, force=None, _configuration=None):  # noqa: E501
        """AttachServersToVolume - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._volume_name = None
        self._access_type = None
        self._lun = None
        self._readonly = None
        self._force = None
        self.discriminator = None

        self.volume_name = volume_name
        if access_type is not None:
            self.access_type = access_type
        if lun is not None:
            self.lun = lun
        if readonly is not None:
            self.readonly = readonly
        if force is not None:
            self.force = force

    @property
    def volume_name(self):
        """Gets the volume_name of this AttachServersToVolume.  # noqa: E501

        The volume ID.  # noqa: E501

        :return: The volume_name of this AttachServersToVolume.  # noqa: E501
        :rtype: str
        """
        return self._volume_name

    @volume_name.setter
    def volume_name(self, volume_name):
        """Sets the volume_name of this AttachServersToVolume.

        The volume ID.  # noqa: E501

        :param volume_name: The volume_name of this AttachServersToVolume.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and volume_name is None:
            raise ValueError("Invalid value for `volume_name`, must not be `None`")  # noqa: E501
        if (self._configuration.client_side_validation and
                volume_name is not None and not re.search(r'^volume-[0-9a-f]{8}$', volume_name)):  # noqa: E501
            raise ValueError(r"Invalid value for `volume_name`, must be a follow pattern or equal to `/^volume-[0-9a-f]{8}$/`")  # noqa: E501

        self._volume_name = volume_name

    @property
    def access_type(self):
        """Gets the access_type of this AttachServersToVolume.  # noqa: E501

        NFS/SMB for NAS, ISCSI for Block.  # noqa: E501

        :return: The access_type of this AttachServersToVolume.  # noqa: E501
        :rtype: str
        """
        return self._access_type

    @access_type.setter
    def access_type(self, access_type):
        """Sets the access_type of this AttachServersToVolume.

        NFS/SMB for NAS, ISCSI for Block.  # noqa: E501

        :param access_type: The access_type of this AttachServersToVolume.  # noqa: E501
        :type: str
        """
        allowed_values = ["NFS", "SMB", "ISCSI"]  # noqa: E501
        if (self._configuration.client_side_validation and
                access_type not in allowed_values):
            raise ValueError(
                "Invalid value for `access_type` ({0}), must be one of {1}"  # noqa: E501
                .format(access_type, allowed_values)
            )

        self._access_type = access_type

    @property
    def lun(self):
        """Gets the lun of this AttachServersToVolume.  # noqa: E501


        :return: The lun of this AttachServersToVolume.  # noqa: E501
        :rtype: int
        """
        return self._lun

    @lun.setter
    def lun(self, lun):
        """Sets the lun of this AttachServersToVolume.


        :param lun: The lun of this AttachServersToVolume.  # noqa: E501
        :type: int
        """

        self._lun = lun

    @property
    def readonly(self):
        """Gets the readonly of this AttachServersToVolume.  # noqa: E501

        Relevant only to NFS/SMB  # noqa: E501

        :return: The readonly of this AttachServersToVolume.  # noqa: E501
        :rtype: str
        """
        return self._readonly

    @readonly.setter
    def readonly(self, readonly):
        """Sets the readonly of this AttachServersToVolume.

        Relevant only to NFS/SMB  # noqa: E501

        :param readonly: The readonly of this AttachServersToVolume.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                readonly not in allowed_values):
            raise ValueError(
                "Invalid value for `readonly` ({0}), must be one of {1}"  # noqa: E501
                .format(readonly, allowed_values)
            )

        self._readonly = readonly

    @property
    def force(self):
        """Gets the force of this AttachServersToVolume.  # noqa: E501

        Required only when volume is already attached to another server.  # noqa: E501

        :return: The force of this AttachServersToVolume.  # noqa: E501
        :rtype: str
        """
        return self._force

    @force.setter
    def force(self, force):
        """Sets the force of this AttachServersToVolume.

        Required only when volume is already attached to another server.  # noqa: E501

        :param force: The force of this AttachServersToVolume.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                force not in allowed_values):
            raise ValueError(
                "Invalid value for `force` ({0}), must be one of {1}"  # noqa: E501
                .format(force, allowed_values)
            )

        self._force = force

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AttachServersToVolume, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AttachServersToVolume):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AttachServersToVolume):
            return True

        return self.to_dict() != other.to_dict()
