# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import CommandCenter
from CommandCenter.api.logs_api import LogsApi  # noqa: E501
from CommandCenter.rest import ApiException


class TestLogsApi(unittest.TestCase):
    """LogsApi unit test stubs"""

    def setUp(self):
        self.api = CommandCenter.api.logs_api.LogsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_address_to_remote_rsyslog_server_list(self):
        """Test case for add_address_to_remote_rsyslog_server_list

        """
        pass

    def test_delete_address_from_remote_rsyslog_server_list(self):
        """Test case for delete_address_from_remote_rsyslog_server_list

        """
        pass

    def test_list_recent_event(self):
        """Test case for list_recent_event

        """
        pass

    def test_retrieve_address_of_remote_rsyslog_server_list(self):
        """Test case for retrieve_address_of_remote_rsyslog_server_list

        """
        pass


if __name__ == '__main__':
    unittest.main()
