# coding: utf-8

"""
    Zadara VPSA Object Storage REST API

    # Overview  This document outlines the methods available for administrating your VPSA&#174; Object Storage. The API supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or through the X-Access-Key header. Alternately, you can use the username and password parameters for authentication, but we do not recommend this method for anything other than possibly retrieving an API key.  By default , all operations are allowed only to VPSA Object Storage admin. Some actions are allowed by an account admin and they will be marked on the action's header  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some time to complete. When using the API, this can cause some actions, such as adding drives to storage policy, to be undesirably asynchronous. You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Metering API  Metering information can be retrieved using the VPSA Object Storage API for the following components:  - Accounts - Users - Drives - Virtual Controllers - Load Balancer Groups - Storage Policies  Metering information returned by the API is subject to the following constraints:  - 10 seconds interval - 1 hour range - 1 minute interval - 1 day range - 1 hour interval - 30 days range  Values outside the accepted range will be returned as 0.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Zios.configuration import Configuration


class AddNewUser(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'username': 'str',
        'email': 'str',
        'account_id': 'str',
        'notify_on_events': 'str',
        'role': 'str'
    }

    attribute_map = {
        'username': 'username',
        'email': 'email',
        'account_id': 'account_id',
        'notify_on_events': 'notify_on_events',
        'role': 'role'
    }

    def __init__(self, username=None, email=None, account_id=None, notify_on_events=None, role=None, _configuration=None):  # noqa: E501
        """AddNewUser - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._username = None
        self._email = None
        self._account_id = None
        self._notify_on_events = None
        self._role = None
        self.discriminator = None

        self.username = username
        self.email = email
        self.account_id = account_id
        if notify_on_events is not None:
            self.notify_on_events = notify_on_events
        self.role = role

    @property
    def username(self):
        """Gets the username of this AddNewUser.  # noqa: E501

        The new username  # noqa: E501

        :return: The username of this AddNewUser.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this AddNewUser.

        The new username  # noqa: E501

        :param username: The username of this AddNewUser.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and username is None:
            raise ValueError("Invalid value for `username`, must not be `None`")  # noqa: E501

        self._username = username

    @property
    def email(self):
        """Gets the email of this AddNewUser.  # noqa: E501

        The new user email  # noqa: E501

        :return: The email of this AddNewUser.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this AddNewUser.

        The new user email  # noqa: E501

        :param email: The email of this AddNewUser.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and email is None:
            raise ValueError("Invalid value for `email`, must not be `None`")  # noqa: E501

        self._email = email

    @property
    def account_id(self):
        """Gets the account_id of this AddNewUser.  # noqa: E501

        Account ID  # noqa: E501

        :return: The account_id of this AddNewUser.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this AddNewUser.

        Account ID  # noqa: E501

        :param account_id: The account_id of this AddNewUser.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and account_id is None:
            raise ValueError("Invalid value for `account_id`, must not be `None`")  # noqa: E501

        self._account_id = account_id

    @property
    def notify_on_events(self):
        """Gets the notify_on_events of this AddNewUser.  # noqa: E501

        Notify the user on system events  # noqa: E501

        :return: The notify_on_events of this AddNewUser.  # noqa: E501
        :rtype: str
        """
        return self._notify_on_events

    @notify_on_events.setter
    def notify_on_events(self, notify_on_events):
        """Sets the notify_on_events of this AddNewUser.

        Notify the user on system events  # noqa: E501

        :param notify_on_events: The notify_on_events of this AddNewUser.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                notify_on_events not in allowed_values):
            raise ValueError(
                "Invalid value for `notify_on_events` ({0}), must be one of {1}"  # noqa: E501
                .format(notify_on_events, allowed_values)
            )

        self._notify_on_events = notify_on_events

    @property
    def role(self):
        """Gets the role of this AddNewUser.  # noqa: E501

        User role in account  # noqa: E501

        :return: The role of this AddNewUser.  # noqa: E501
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this AddNewUser.

        User role in account  # noqa: E501

        :param role: The role of this AddNewUser.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and role is None:
            raise ValueError("Invalid value for `role`, must not be `None`")  # noqa: E501
        allowed_values = ["zios_admin", "account_admin", "member"]  # noqa: E501
        if (self._configuration.client_side_validation and
                role not in allowed_values):
            raise ValueError(
                "Invalid value for `role` ({0}), must be one of {1}"  # noqa: E501
                .format(role, allowed_values)
            )

        self._role = role

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AddNewUser, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddNewUser):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AddNewUser):
            return True

        return self.to_dict() != other.to_dict()
