# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class CreateRosDestination(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'type': 'str',
        'bucket': 'str',
        'endpoint': 'str',
        'username': 'str',
        'password': 'str',
        'connect_via': 'str',
        'allow_lifecycle_policies': 'bool',
        'proxyhost': 'str',
        'proxyport': 'str',
        'proxyuser': 'str',
        'proxypassword': 'str'
    }

    attribute_map = {
        'name': 'name',
        'type': 'type',
        'bucket': 'bucket',
        'endpoint': 'endpoint',
        'username': 'username',
        'password': 'password',
        'connect_via': 'connectVia',
        'allow_lifecycle_policies': 'allow_lifecycle_policies',
        'proxyhost': 'proxyhost',
        'proxyport': 'proxyport',
        'proxyuser': 'proxyuser',
        'proxypassword': 'proxypassword'
    }

    def __init__(self, name=None, type=None, bucket=None, endpoint=None, username=None, password=None, connect_via=None, allow_lifecycle_policies=None, proxyhost=None, proxyport=None, proxyuser=None, proxypassword=None, _configuration=None):  # noqa: E501
        """CreateRosDestination - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._type = None
        self._bucket = None
        self._endpoint = None
        self._username = None
        self._password = None
        self._connect_via = None
        self._allow_lifecycle_policies = None
        self._proxyhost = None
        self._proxyport = None
        self._proxyuser = None
        self._proxypassword = None
        self.discriminator = None

        self.name = name
        self.type = type
        self.bucket = bucket
        self.endpoint = endpoint
        self.username = username
        self.password = password
        self.connect_via = connect_via
        self.allow_lifecycle_policies = allow_lifecycle_policies
        if proxyhost is not None:
            self.proxyhost = proxyhost
        if proxyport is not None:
            self.proxyport = proxyport
        if proxyuser is not None:
            self.proxyuser = proxyuser
        if proxypassword is not None:
            self.proxypassword = proxypassword

    @property
    def name(self):
        """Gets the name of this CreateRosDestination.  # noqa: E501

        Display Name for remote object storage  # noqa: E501

        :return: The name of this CreateRosDestination.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateRosDestination.

        Display Name for remote object storage  # noqa: E501

        :param name: The name of this CreateRosDestination.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def type(self):
        """Gets the type of this CreateRosDestination.  # noqa: E501

        Type for remote object storage.  # noqa: E501

        :return: The type of this CreateRosDestination.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this CreateRosDestination.

        Type for remote object storage.  # noqa: E501

        :param type: The type of this CreateRosDestination.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["AWS_S3", "GCS_S3", "ZIOS_S3", "AZURE"]  # noqa: E501
        if (self._configuration.client_side_validation and
                type not in allowed_values):
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def bucket(self):
        """Gets the bucket of this CreateRosDestination.  # noqa: E501

        remote object storage bucket name / Azure cloud container name  # noqa: E501

        :return: The bucket of this CreateRosDestination.  # noqa: E501
        :rtype: str
        """
        return self._bucket

    @bucket.setter
    def bucket(self, bucket):
        """Sets the bucket of this CreateRosDestination.

        remote object storage bucket name / Azure cloud container name  # noqa: E501

        :param bucket: The bucket of this CreateRosDestination.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and bucket is None:
            raise ValueError("Invalid value for `bucket`, must not be `None`")  # noqa: E501

        self._bucket = bucket

    @property
    def endpoint(self):
        """Gets the endpoint of this CreateRosDestination.  # noqa: E501

        Endpoint for remote object storage (use 'storage.googleapis.com' for Google cloud, use 'blob.core.windows.net' for Azure cloud).  # noqa: E501

        :return: The endpoint of this CreateRosDestination.  # noqa: E501
        :rtype: str
        """
        return self._endpoint

    @endpoint.setter
    def endpoint(self, endpoint):
        """Sets the endpoint of this CreateRosDestination.

        Endpoint for remote object storage (use 'storage.googleapis.com' for Google cloud, use 'blob.core.windows.net' for Azure cloud).  # noqa: E501

        :param endpoint: The endpoint of this CreateRosDestination.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and endpoint is None:
            raise ValueError("Invalid value for `endpoint`, must not be `None`")  # noqa: E501

        self._endpoint = endpoint

    @property
    def username(self):
        """Gets the username of this CreateRosDestination.  # noqa: E501

        Access Key ID for remote object storage / Account in Azure cloud  # noqa: E501

        :return: The username of this CreateRosDestination.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this CreateRosDestination.

        Access Key ID for remote object storage / Account in Azure cloud  # noqa: E501

        :param username: The username of this CreateRosDestination.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and username is None:
            raise ValueError("Invalid value for `username`, must not be `None`")  # noqa: E501

        self._username = username

    @property
    def password(self):
        """Gets the password of this CreateRosDestination.  # noqa: E501

        Secret Access Key for remote object storage / Storage account key in Azure cloud.  # noqa: E501

        :return: The password of this CreateRosDestination.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this CreateRosDestination.

        Secret Access Key for remote object storage / Storage account key in Azure cloud.  # noqa: E501

        :param password: The password of this CreateRosDestination.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and password is None:
            raise ValueError("Invalid value for `password`, must not be `None`")  # noqa: E501

        self._password = password

    @property
    def connect_via(self):
        """Gets the connect_via of this CreateRosDestination.  # noqa: E501

        Connection method to Azure cloud.  # noqa: E501

        :return: The connect_via of this CreateRosDestination.  # noqa: E501
        :rtype: str
        """
        return self._connect_via

    @connect_via.setter
    def connect_via(self, connect_via):
        """Sets the connect_via of this CreateRosDestination.

        Connection method to Azure cloud.  # noqa: E501

        :param connect_via: The connect_via of this CreateRosDestination.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and connect_via is None:
            raise ValueError("Invalid value for `connect_via`, must not be `None`")  # noqa: E501
        allowed_values = ["fe", "public"]  # noqa: E501
        if (self._configuration.client_side_validation and
                connect_via not in allowed_values):
            raise ValueError(
                "Invalid value for `connect_via` ({0}), must be one of {1}"  # noqa: E501
                .format(connect_via, allowed_values)
            )

        self._connect_via = connect_via

    @property
    def allow_lifecycle_policies(self):
        """Gets the allow_lifecycle_policies of this CreateRosDestination.  # noqa: E501

        Allow bucket to have lifecycle policies - use 'true'.  # noqa: E501

        :return: The allow_lifecycle_policies of this CreateRosDestination.  # noqa: E501
        :rtype: bool
        """
        return self._allow_lifecycle_policies

    @allow_lifecycle_policies.setter
    def allow_lifecycle_policies(self, allow_lifecycle_policies):
        """Sets the allow_lifecycle_policies of this CreateRosDestination.

        Allow bucket to have lifecycle policies - use 'true'.  # noqa: E501

        :param allow_lifecycle_policies: The allow_lifecycle_policies of this CreateRosDestination.  # noqa: E501
        :type: bool
        """
        if self._configuration.client_side_validation and allow_lifecycle_policies is None:
            raise ValueError("Invalid value for `allow_lifecycle_policies`, must not be `None`")  # noqa: E501

        self._allow_lifecycle_policies = allow_lifecycle_policies

    @property
    def proxyhost(self):
        """Gets the proxyhost of this CreateRosDestination.  # noqa: E501

        Proxy host  # noqa: E501

        :return: The proxyhost of this CreateRosDestination.  # noqa: E501
        :rtype: str
        """
        return self._proxyhost

    @proxyhost.setter
    def proxyhost(self, proxyhost):
        """Sets the proxyhost of this CreateRosDestination.

        Proxy host  # noqa: E501

        :param proxyhost: The proxyhost of this CreateRosDestination.  # noqa: E501
        :type: str
        """

        self._proxyhost = proxyhost

    @property
    def proxyport(self):
        """Gets the proxyport of this CreateRosDestination.  # noqa: E501

        Port for proxy  # noqa: E501

        :return: The proxyport of this CreateRosDestination.  # noqa: E501
        :rtype: str
        """
        return self._proxyport

    @proxyport.setter
    def proxyport(self, proxyport):
        """Sets the proxyport of this CreateRosDestination.

        Port for proxy  # noqa: E501

        :param proxyport: The proxyport of this CreateRosDestination.  # noqa: E501
        :type: str
        """

        self._proxyport = proxyport

    @property
    def proxyuser(self):
        """Gets the proxyuser of this CreateRosDestination.  # noqa: E501

        Username for proxy  # noqa: E501

        :return: The proxyuser of this CreateRosDestination.  # noqa: E501
        :rtype: str
        """
        return self._proxyuser

    @proxyuser.setter
    def proxyuser(self, proxyuser):
        """Sets the proxyuser of this CreateRosDestination.

        Username for proxy  # noqa: E501

        :param proxyuser: The proxyuser of this CreateRosDestination.  # noqa: E501
        :type: str
        """

        self._proxyuser = proxyuser

    @property
    def proxypassword(self):
        """Gets the proxypassword of this CreateRosDestination.  # noqa: E501

        Password for proxy  # noqa: E501

        :return: The proxypassword of this CreateRosDestination.  # noqa: E501
        :rtype: str
        """
        return self._proxypassword

    @proxypassword.setter
    def proxypassword(self, proxypassword):
        """Sets the proxypassword of this CreateRosDestination.

        Password for proxy  # noqa: E501

        :param proxypassword: The proxypassword of this CreateRosDestination.  # noqa: E501
        :type: str
        """

        self._proxypassword = proxypassword

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateRosDestination, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateRosDestination):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateRosDestination):
            return True

        return self.to_dict() != other.to_dict()
