# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import CommandCenter
from CommandCenter.api.vlan_api import VLANApi  # noqa: E501
from CommandCenter.rest import ApiException


class TestVLANApi(unittest.TestCase):
    """VLANApi unit test stubs"""

    def setUp(self):
        self.api = CommandCenter.api.vlan_api.VLANApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_provisioned_vlan_or_range(self):
        """Test case for add_provisioned_vlan_or_range

        """
        pass

    def test_allocate_vlan_to_cloud_user(self):
        """Test case for allocate_vlan_to_cloud_user

        """
        pass

    def test_deallocate_vlan_to_cloud_user(self):
        """Test case for deallocate_vlan_to_cloud_user

        """
        pass

    def test_delete_vlans(self):
        """Test case for delete_vlans

        """
        pass

    def test_delete_vrid_from_vlan(self):
        """Test case for delete_vrid_from_vlan

        """
        pass

    def test_get_vlans(self):
        """Test case for get_vlans

        """
        pass

    def test_populate_vrid_in_vlan(self):
        """Test case for populate_vrid_in_vlan

        """
        pass

    def test_reserve_provisioned_vlan(self):
        """Test case for reserve_provisioned_vlan

        """
        pass

    def test_reserve_vrid_for_vlan(self):
        """Test case for reserve_vrid_for_vlan

        """
        pass

    def test_set_default_vlan_for_cloud_user(self):
        """Test case for set_default_vlan_for_cloud_user

        """
        pass

    def test_unreserve_provisioned_vlan(self):
        """Test case for unreserve_provisioned_vlan

        """
        pass

    def test_unreserve_vrid_from_vlan(self):
        """Test case for unreserve_vrid_from_vlan

        """
        pass


if __name__ == '__main__':
    unittest.main()
