# coding: utf-8

# flake8: noqa

"""
    Zadara VPSA Object Storage REST API

    # Overview  This document outlines the methods available for administrating your VPSA&#174; Object Storage. The API supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or through the X-Access-Key header. Alternately, you can use the username and password parameters for authentication, but we do not recommend this method for anything other than possibly retrieving an API key.  By default , all operations are allowed only to VPSA Object Storage admin. Some actions are allowed by an account admin and they will be marked on the action's header  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some time to complete. When using the API, this can cause some actions, such as adding drives to storage policy, to be undesirably asynchronous. You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Metering API  Metering information can be retrieved using the VPSA Object Storage API for the following components:  - Accounts - Users - Drives - Virtual Controllers - Load Balancer Groups - Storage Policies  Metering information returned by the API is subject to the following constraints:  - 10 seconds interval - 1 hour range - 1 minute interval - 1 day range - 1 hour interval - 30 days range  Values outside the accepted range will be returned as 0.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from Zios.api.accounts_api import AccountsApi
from Zios.api.drives_api import DrivesApi
from Zios.api.load_balancer_api import LoadBalancerApi
from Zios.api.logs_api import LogsApi
from Zios.api.object_storage_destinations_api import ObjectStorageDestinationsApi
from Zios.api.roles_api import RolesApi
from Zios.api.settings_api import SettingsApi
from Zios.api.storage_policies_api import StoragePoliciesApi
from Zios.api.usage_reports_api import UsageReportsApi
from Zios.api.users_api import UsersApi
from Zios.api.virtual_controllers_api import VirtualControllersApi

# import ApiClient
from Zios.api_client import ApiClient
from Zios.configuration import Configuration
# import models into sdk package
from Zios.models.add_new_user import AddNewUser
from Zios.models.allow_tenant_name_in_object_stroage_url import AllowTenantNameInObjectStroageUrl
from Zios.models.change_mtu_for_network_interface import ChangeMtuForNetworkInterface
from Zios.models.change_password import ChangePassword
from Zios.models.change_region import ChangeRegion
from Zios.models.change_user_pass_by_code import ChangeUserPassByCode
from Zios.models.change_user_role import ChangeUserRole
from Zios.models.create_account import CreateAccount
from Zios.models.create_account_requests import CreateAccountRequests
from Zios.models.create_object_storage_destination import CreateObjectStorageDestination
from Zios.models.default import Default
from Zios.models.default_response import DefaultResponse
from Zios.models.define_custom_dns_servers import DefineCustomDnsServers
from Zios.models.delete_account import DeleteAccount
from Zios.models.delete_drives_from_policy import DeleteDrivesFromPolicy
from Zios.models.delete_object_storage_destination import DeleteObjectStorageDestination
from Zios.models.delete_proxy_virtual_controller import DeleteProxyVirtualController
from Zios.models.error import Error
from Zios.models.get_auth_token import GetAuthToken
from Zios.models.inline_response200 import InlineResponse200
from Zios.models.inline_response2001 import InlineResponse2001
from Zios.models.inline_response20010 import InlineResponse20010
from Zios.models.inline_response20010_response import InlineResponse20010Response
from Zios.models.inline_response20011 import InlineResponse20011
from Zios.models.inline_response20011_response import InlineResponse20011Response
from Zios.models.inline_response20012 import InlineResponse20012
from Zios.models.inline_response20012_objects import InlineResponse20012Objects
from Zios.models.inline_response20013 import InlineResponse20013
from Zios.models.inline_response20013_objects import InlineResponse20013Objects
from Zios.models.inline_response20014 import InlineResponse20014
from Zios.models.inline_response20014_objects import InlineResponse20014Objects
from Zios.models.inline_response20015 import InlineResponse20015
from Zios.models.inline_response20015_response import InlineResponse20015Response
from Zios.models.inline_response20015_response_disks import InlineResponse20015ResponseDisks
from Zios.models.inline_response20016 import InlineResponse20016
from Zios.models.inline_response20016_response import InlineResponse20016Response
from Zios.models.inline_response20016_response_disk import InlineResponse20016ResponseDisk
from Zios.models.inline_response20017 import InlineResponse20017
from Zios.models.inline_response20017_response import InlineResponse20017Response
from Zios.models.inline_response20017_response_lbgs import InlineResponse20017ResponseLbgs
from Zios.models.inline_response20018 import InlineResponse20018
from Zios.models.inline_response20018_response import InlineResponse20018Response
from Zios.models.inline_response20018_response_lbg import InlineResponse20018ResponseLbg
from Zios.models.inline_response20019 import InlineResponse20019
from Zios.models.inline_response20019_response import InlineResponse20019Response
from Zios.models.inline_response20019_response_messages import InlineResponse20019ResponseMessages
from Zios.models.inline_response2001_response import InlineResponse2001Response
from Zios.models.inline_response2002 import InlineResponse2002
from Zios.models.inline_response20020 import InlineResponse20020
from Zios.models.inline_response20020_response import InlineResponse20020Response
from Zios.models.inline_response20020_response_access_logs import InlineResponse20020ResponseAccessLogs
from Zios.models.inline_response20021 import InlineResponse20021
from Zios.models.inline_response20021_response import InlineResponse20021Response
from Zios.models.inline_response20021_response_container_replication_targets import InlineResponse20021ResponseContainerReplicationTargets
from Zios.models.inline_response20022 import InlineResponse20022
from Zios.models.inline_response20022_response import InlineResponse20022Response
from Zios.models.inline_response20023 import InlineResponse20023
from Zios.models.inline_response20023_response import InlineResponse20023Response
from Zios.models.inline_response20023_response_target import InlineResponse20023ResponseTarget
from Zios.models.inline_response20024 import InlineResponse20024
from Zios.models.inline_response20024_response import InlineResponse20024Response
from Zios.models.inline_response20025 import InlineResponse20025
from Zios.models.inline_response20025_response import InlineResponse20025Response
from Zios.models.inline_response20026 import InlineResponse20026
from Zios.models.inline_response20026_response import InlineResponse20026Response
from Zios.models.inline_response20026_response_roles import InlineResponse20026ResponseRoles
from Zios.models.inline_response20027 import InlineResponse20027
from Zios.models.inline_response20027_response import InlineResponse20027Response
from Zios.models.inline_response20028 import InlineResponse20028
from Zios.models.inline_response20028_response import InlineResponse20028Response
from Zios.models.inline_response20029 import InlineResponse20029
from Zios.models.inline_response20029_response import InlineResponse20029Response
from Zios.models.inline_response2002_response import InlineResponse2002Response
from Zios.models.inline_response2002_response_account import InlineResponse2002ResponseAccount
from Zios.models.inline_response2003 import InlineResponse2003
from Zios.models.inline_response20030 import InlineResponse20030
from Zios.models.inline_response20030_response import InlineResponse20030Response
from Zios.models.inline_response20031 import InlineResponse20031
from Zios.models.inline_response20031_response import InlineResponse20031Response
from Zios.models.inline_response20032 import InlineResponse20032
from Zios.models.inline_response20032_response import InlineResponse20032Response
from Zios.models.inline_response20033 import InlineResponse20033
from Zios.models.inline_response20033_response import InlineResponse20033Response
from Zios.models.inline_response20034 import InlineResponse20034
from Zios.models.inline_response20034_response import InlineResponse20034Response
from Zios.models.inline_response20034_response_policies import InlineResponse20034ResponsePolicies
from Zios.models.inline_response20035 import InlineResponse20035
from Zios.models.inline_response20035_response import InlineResponse20035Response
from Zios.models.inline_response20035_response_policy import InlineResponse20035ResponsePolicy
from Zios.models.inline_response20036 import InlineResponse20036
from Zios.models.inline_response20036_response import InlineResponse20036Response
from Zios.models.inline_response20037 import InlineResponse20037
from Zios.models.inline_response20037_response import InlineResponse20037Response
from Zios.models.inline_response20038 import InlineResponse20038
from Zios.models.inline_response20038_response import InlineResponse20038Response
from Zios.models.inline_response20039 import InlineResponse20039
from Zios.models.inline_response20039_objects import InlineResponse20039Objects
from Zios.models.inline_response2003_response import InlineResponse2003Response
from Zios.models.inline_response2004 import InlineResponse2004
from Zios.models.inline_response20040 import InlineResponse20040
from Zios.models.inline_response20040_response import InlineResponse20040Response
from Zios.models.inline_response20040_response_usage import InlineResponse20040ResponseUsage
from Zios.models.inline_response20040_response_usage_account_usage_summary import InlineResponse20040ResponseUsageAccountUsageSummary
from Zios.models.inline_response20040_response_usage_report_header import InlineResponse20040ResponseUsageReportHeader
from Zios.models.inline_response20040_response_usage_report_header_policy_capacity_usage_cost_gbmonth import InlineResponse20040ResponseUsageReportHeaderPolicyCapacityUsageCostGbmonth
from Zios.models.inline_response20040_response_usage_report_header_reporting_interval import InlineResponse20040ResponseUsageReportHeaderReportingInterval
from Zios.models.inline_response20040_response_usage_usage_summary import InlineResponse20040ResponseUsageUsageSummary
from Zios.models.inline_response20041 import InlineResponse20041
from Zios.models.inline_response20041_response import InlineResponse20041Response
from Zios.models.inline_response20041_response_roles import InlineResponse20041ResponseRoles
from Zios.models.inline_response20041_response_users import InlineResponse20041ResponseUsers
from Zios.models.inline_response20041_response_zios_data import InlineResponse20041ResponseZiosData
from Zios.models.inline_response20041_response_zios_data_zios_user import InlineResponse20041ResponseZiosDataZiosUser
from Zios.models.inline_response20041_response_zios_data_zios_user_roles import InlineResponse20041ResponseZiosDataZiosUserRoles
from Zios.models.inline_response20042 import InlineResponse20042
from Zios.models.inline_response20042_response import InlineResponse20042Response
from Zios.models.inline_response20043 import InlineResponse20043
from Zios.models.inline_response20043_response import InlineResponse20043Response
from Zios.models.inline_response20043_response_user import InlineResponse20043ResponseUser
from Zios.models.inline_response20044 import InlineResponse20044
from Zios.models.inline_response20044_response import InlineResponse20044Response
from Zios.models.inline_response20044_response_user import InlineResponse20044ResponseUser
from Zios.models.inline_response20044_response_user_zios_data import InlineResponse20044ResponseUserZiosData
from Zios.models.inline_response20044_response_user_zios_data_zios_user import InlineResponse20044ResponseUserZiosDataZiosUser
from Zios.models.inline_response20045 import InlineResponse20045
from Zios.models.inline_response20045_response import InlineResponse20045Response
from Zios.models.inline_response20046 import InlineResponse20046
from Zios.models.inline_response20046_response import InlineResponse20046Response
from Zios.models.inline_response20047 import InlineResponse20047
from Zios.models.inline_response20047_response import InlineResponse20047Response
from Zios.models.inline_response20048 import InlineResponse20048
from Zios.models.inline_response20048_response import InlineResponse20048Response
from Zios.models.inline_response20048_response_credentials import InlineResponse20048ResponseCredentials
from Zios.models.inline_response20049 import InlineResponse20049
from Zios.models.inline_response20049_response import InlineResponse20049Response
from Zios.models.inline_response20049_response_user import InlineResponse20049ResponseUser
from Zios.models.inline_response20049_response_user_roles import InlineResponse20049ResponseUserRoles
from Zios.models.inline_response20049_response_user_zios_data import InlineResponse20049ResponseUserZiosData
from Zios.models.inline_response20049_response_user_zios_data_zios_user import InlineResponse20049ResponseUserZiosDataZiosUser
from Zios.models.inline_response20049_response_user_zios_data_zios_user_roles import InlineResponse20049ResponseUserZiosDataZiosUserRoles
from Zios.models.inline_response2004_response import InlineResponse2004Response
from Zios.models.inline_response2004_response_users import InlineResponse2004ResponseUsers
from Zios.models.inline_response2005 import InlineResponse2005
from Zios.models.inline_response20050 import InlineResponse20050
from Zios.models.inline_response20051 import InlineResponse20051
from Zios.models.inline_response20052 import InlineResponse20052
from Zios.models.inline_response20052_response import InlineResponse20052Response
from Zios.models.inline_response20052_response_vcs import InlineResponse20052ResponseVcs
from Zios.models.inline_response20053 import InlineResponse20053
from Zios.models.inline_response20053_response import InlineResponse20053Response
from Zios.models.inline_response20053_response_vc import InlineResponse20053ResponseVc
from Zios.models.inline_response20054 import InlineResponse20054
from Zios.models.inline_response20054_response import InlineResponse20054Response
from Zios.models.inline_response20054_response_disks import InlineResponse20054ResponseDisks
from Zios.models.inline_response20055 import InlineResponse20055
from Zios.models.inline_response20055_response import InlineResponse20055Response
from Zios.models.inline_response20056 import InlineResponse20056
from Zios.models.inline_response20056_objects import InlineResponse20056Objects
from Zios.models.inline_response2005_response import InlineResponse2005Response
from Zios.models.inline_response2006 import InlineResponse2006
from Zios.models.inline_response2006_response import InlineResponse2006Response
from Zios.models.inline_response2007 import InlineResponse2007
from Zios.models.inline_response2007_response import InlineResponse2007Response
from Zios.models.inline_response2008 import InlineResponse2008
from Zios.models.inline_response2008_response import InlineResponse2008Response
from Zios.models.inline_response2008_response_arguments import InlineResponse2008ResponseArguments
from Zios.models.inline_response2008_response_requests import InlineResponse2008ResponseRequests
from Zios.models.inline_response2009 import InlineResponse2009
from Zios.models.inline_response2009_response import InlineResponse2009Response
from Zios.models.inline_response200_response import InlineResponse200Response
from Zios.models.inline_response200_response_accounts import InlineResponse200ResponseAccounts
from Zios.models.issue_temp_code_to_mail import IssueTempCodeToMail
from Zios.models.reset_token import ResetToken
from Zios.models.reset_user_s3_keys import ResetUserS3Keys
from Zios.models.restore_encryption import RestoreEncryption
from Zios.models.set_api_errors_alerts import SetApiErrorsAlerts
from Zios.models.set_api_hostname import SetApiHostname
from Zios.models.set_api_ip import SetApiIp
from Zios.models.set_billing_currency import SetBillingCurrency
from Zios.models.set_containers_virtual_hosted_style_support import SetContainersVirtualHostedStyleSupport
from Zios.models.set_data_transfer_pricing import SetDataTransferPricing
from Zios.models.set_encryption import SetEncryption
from Zios.models.set_global_rate_limit import SetGlobalRateLimit
from Zios.models.set_gradual_policy_expansion_percentage import SetGradualPolicyExpansionPercentage
from Zios.models.set_lb_mode import SetLbMode
from Zios.models.set_public_ip_hostname import SetPublicIpHostname
from Zios.models.ssl_termination import SslTermination
from Zios.models.token_expiration import TokenExpiration
from Zios.models.update_object_storage_destination import UpdateObjectStorageDestination
from Zios.models.update_storage_policy import UpdateStoragePolicy
from Zios.models.upload_ssl_pem import UploadSslPem
