# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class InlineResponse20026DriveTypesDriveType(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'type': 'str',
        'size': 'int',
        'rpm': 'str',
        'inventory': 'InlineResponse20026DriveTypesDriveTypeInventory',
        'total': 'int',
        'product_id': 'str',
        'internal_id': 'int'
    }

    attribute_map = {
        'name': 'name',
        'type': 'type',
        'size': 'size',
        'rpm': 'rpm',
        'inventory': 'inventory',
        'total': 'total',
        'product_id': 'product_id',
        'internal_id': 'internal_id'
    }

    def __init__(self, name=None, type=None, size=None, rpm=None, inventory=None, total=None, product_id=None, internal_id=None, _configuration=None):  # noqa: E501
        """InlineResponse20026DriveTypesDriveType - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._type = None
        self._size = None
        self._rpm = None
        self._inventory = None
        self._total = None
        self._product_id = None
        self._internal_id = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if type is not None:
            self.type = type
        if size is not None:
            self.size = size
        if rpm is not None:
            self.rpm = rpm
        if inventory is not None:
            self.inventory = inventory
        if total is not None:
            self.total = total
        if product_id is not None:
            self.product_id = product_id
        if internal_id is not None:
            self.internal_id = internal_id

    @property
    def name(self):
        """Gets the name of this InlineResponse20026DriveTypesDriveType.  # noqa: E501


        :return: The name of this InlineResponse20026DriveTypesDriveType.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse20026DriveTypesDriveType.


        :param name: The name of this InlineResponse20026DriveTypesDriveType.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def type(self):
        """Gets the type of this InlineResponse20026DriveTypesDriveType.  # noqa: E501


        :return: The type of this InlineResponse20026DriveTypesDriveType.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this InlineResponse20026DriveTypesDriveType.


        :param type: The type of this InlineResponse20026DriveTypesDriveType.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def size(self):
        """Gets the size of this InlineResponse20026DriveTypesDriveType.  # noqa: E501


        :return: The size of this InlineResponse20026DriveTypesDriveType.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this InlineResponse20026DriveTypesDriveType.


        :param size: The size of this InlineResponse20026DriveTypesDriveType.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def rpm(self):
        """Gets the rpm of this InlineResponse20026DriveTypesDriveType.  # noqa: E501


        :return: The rpm of this InlineResponse20026DriveTypesDriveType.  # noqa: E501
        :rtype: str
        """
        return self._rpm

    @rpm.setter
    def rpm(self, rpm):
        """Sets the rpm of this InlineResponse20026DriveTypesDriveType.


        :param rpm: The rpm of this InlineResponse20026DriveTypesDriveType.  # noqa: E501
        :type: str
        """

        self._rpm = rpm

    @property
    def inventory(self):
        """Gets the inventory of this InlineResponse20026DriveTypesDriveType.  # noqa: E501


        :return: The inventory of this InlineResponse20026DriveTypesDriveType.  # noqa: E501
        :rtype: InlineResponse20026DriveTypesDriveTypeInventory
        """
        return self._inventory

    @inventory.setter
    def inventory(self, inventory):
        """Sets the inventory of this InlineResponse20026DriveTypesDriveType.


        :param inventory: The inventory of this InlineResponse20026DriveTypesDriveType.  # noqa: E501
        :type: InlineResponse20026DriveTypesDriveTypeInventory
        """

        self._inventory = inventory

    @property
    def total(self):
        """Gets the total of this InlineResponse20026DriveTypesDriveType.  # noqa: E501


        :return: The total of this InlineResponse20026DriveTypesDriveType.  # noqa: E501
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this InlineResponse20026DriveTypesDriveType.


        :param total: The total of this InlineResponse20026DriveTypesDriveType.  # noqa: E501
        :type: int
        """

        self._total = total

    @property
    def product_id(self):
        """Gets the product_id of this InlineResponse20026DriveTypesDriveType.  # noqa: E501


        :return: The product_id of this InlineResponse20026DriveTypesDriveType.  # noqa: E501
        :rtype: str
        """
        return self._product_id

    @product_id.setter
    def product_id(self, product_id):
        """Sets the product_id of this InlineResponse20026DriveTypesDriveType.


        :param product_id: The product_id of this InlineResponse20026DriveTypesDriveType.  # noqa: E501
        :type: str
        """

        self._product_id = product_id

    @property
    def internal_id(self):
        """Gets the internal_id of this InlineResponse20026DriveTypesDriveType.  # noqa: E501


        :return: The internal_id of this InlineResponse20026DriveTypesDriveType.  # noqa: E501
        :rtype: int
        """
        return self._internal_id

    @internal_id.setter
    def internal_id(self, internal_id):
        """Sets the internal_id of this InlineResponse20026DriveTypesDriveType.


        :param internal_id: The internal_id of this InlineResponse20026DriveTypesDriveType.  # noqa: E501
        :type: int
        """

        self._internal_id = internal_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20026DriveTypesDriveType, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20026DriveTypesDriveType):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20026DriveTypesDriveType):
            return True

        return self.to_dict() != other.to_dict()
