# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class UpdateUser(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'email': 'str',
        'firstname': 'str',
        'lastname': 'str',
        'admin': 'bool',
        'role_ids': 'list[int]',
        'current_password': 'str',
        'password': 'str'
    }

    attribute_map = {
        'email': 'email',
        'firstname': 'firstname',
        'lastname': 'lastname',
        'admin': 'admin',
        'role_ids': 'role_ids',
        'current_password': 'current_password',
        'password': 'password'
    }

    def __init__(self, email=None, firstname=None, lastname=None, admin=None, role_ids=None, current_password=None, password=None, _configuration=None):  # noqa: E501
        """UpdateUser - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._email = None
        self._firstname = None
        self._lastname = None
        self._admin = None
        self._role_ids = None
        self._current_password = None
        self._password = None
        self.discriminator = None

        if email is not None:
            self.email = email
        if firstname is not None:
            self.firstname = firstname
        if lastname is not None:
            self.lastname = lastname
        if admin is not None:
            self.admin = admin
        if role_ids is not None:
            self.role_ids = role_ids
        if current_password is not None:
            self.current_password = current_password
        if password is not None:
            self.password = password

    @property
    def email(self):
        """Gets the email of this UpdateUser.  # noqa: E501

        email  # noqa: E501

        :return: The email of this UpdateUser.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this UpdateUser.

        email  # noqa: E501

        :param email: The email of this UpdateUser.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def firstname(self):
        """Gets the firstname of this UpdateUser.  # noqa: E501


        :return: The firstname of this UpdateUser.  # noqa: E501
        :rtype: str
        """
        return self._firstname

    @firstname.setter
    def firstname(self, firstname):
        """Sets the firstname of this UpdateUser.


        :param firstname: The firstname of this UpdateUser.  # noqa: E501
        :type: str
        """

        self._firstname = firstname

    @property
    def lastname(self):
        """Gets the lastname of this UpdateUser.  # noqa: E501


        :return: The lastname of this UpdateUser.  # noqa: E501
        :rtype: str
        """
        return self._lastname

    @lastname.setter
    def lastname(self, lastname):
        """Sets the lastname of this UpdateUser.


        :param lastname: The lastname of this UpdateUser.  # noqa: E501
        :type: str
        """

        self._lastname = lastname

    @property
    def admin(self):
        """Gets the admin of this UpdateUser.  # noqa: E501


        :return: The admin of this UpdateUser.  # noqa: E501
        :rtype: bool
        """
        return self._admin

    @admin.setter
    def admin(self, admin):
        """Sets the admin of this UpdateUser.


        :param admin: The admin of this UpdateUser.  # noqa: E501
        :type: bool
        """

        self._admin = admin

    @property
    def role_ids(self):
        """Gets the role_ids of this UpdateUser.  # noqa: E501


        :return: The role_ids of this UpdateUser.  # noqa: E501
        :rtype: list[int]
        """
        return self._role_ids

    @role_ids.setter
    def role_ids(self, role_ids):
        """Sets the role_ids of this UpdateUser.


        :param role_ids: The role_ids of this UpdateUser.  # noqa: E501
        :type: list[int]
        """

        self._role_ids = role_ids

    @property
    def current_password(self):
        """Gets the current_password of this UpdateUser.  # noqa: E501


        :return: The current_password of this UpdateUser.  # noqa: E501
        :rtype: str
        """
        return self._current_password

    @current_password.setter
    def current_password(self, current_password):
        """Sets the current_password of this UpdateUser.


        :param current_password: The current_password of this UpdateUser.  # noqa: E501
        :type: str
        """

        self._current_password = current_password

    @property
    def password(self):
        """Gets the password of this UpdateUser.  # noqa: E501


        :return: The password of this UpdateUser.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this UpdateUser.


        :param password: The password of this UpdateUser.  # noqa: E501
        :type: str
        """

        self._password = password

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateUser, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateUser):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateUser):
            return True

        return self.to_dict() != other.to_dict()
